# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.models.object import Object


class RangerSystemCheckResponse(object):

    """Implementation of the 'RangerSystemCheckResponse' model.

    TODO: type model description here.

    Attributes:
        data (object): TODO: type description here.
        success (bool): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "data": 'data',
        "success": 'success'
    }

    def __init__(self,
                 data=None,
                 success=None):
        """Constructor for the RangerSystemCheckResponse class"""

        # Initialize members of the class
        self.data = data 
        self.success = success 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        data = Object.from_dictionary(dictionary.get('data')) if dictionary.get('data') else None
        success = dictionary.get("success") if "success" in dictionary.keys() else None
        # Return an object of this model
        return cls(data,
                   success)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.models.new_taskobject import NewTaskobject


class Createanewtask(object):

    """Implementation of the 'Createanewtask' model.

    TODO: type model description here.

    Attributes:
        site_id (int): TODO: type description here.
        params (NewTaskobject): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "site_id": 'site_id',
        "params": 'params'
    }

    def __init__(self,
                 site_id=None,
                 params=None):
        """Constructor for the Createanewtask class"""

        # Initialize members of the class
        self.site_id = site_id 
        self.params = params 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        site_id = dictionary.get("site_id") if dictionary.get("site_id") else None
        params = NewTaskobject.from_dictionary(dictionary.get('params')) if dictionary.get('params') else None
        # Return an object of this model
        return cls(site_id,
                   params)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from ctddocumentation.api_helper import APIHelper
from ctddocumentation.configuration import Server
from ctddocumentation.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from ctddocumentation.http.http_method_enum import HttpMethodEnum
from apimatic_core.authentication.multiple.single_auth import Single
from apimatic_core.authentication.multiple.and_auth_group import And
from apimatic_core.authentication.multiple.or_auth_group import Or
from ctddocumentation.models.get_queries_response import GetQueriesResponse
from ctddocumentation.models.create_a_new_query_response import CreateANewQueryResponse
from ctddocumentation.models.delete_a_query_response import DeleteAQueryResponse
from ctddocumentation.models.object import Object


class QueriesController(BaseController):

    """A Controller to access Endpoints in the ctddocumentation API."""
    def __init__(self, config):
        super(QueriesController, self).__init__(config)

    def get_queries(self,
                    sort=None,
                    page=None,
                    per_page=None,
                    name__icontains=None,
                    site_id__exact=None):
        """Does a GET request to /ranger/queries.

        Get all queries and their information

        Args:
            sort (Sort1Enum, optional): TODO: type description here.
            page (int, optional): TODO: type description here.
            per_page (int, optional): TODO: type description here.
            name__icontains (string, optional): TODO: type description here.
            site_id__exact (int, optional): TODO: type description here.

        Returns:
            GetQueriesResponse: Response from the API. Successful Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/queries')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('sort')
                         .value(sort))
            .query_param(Parameter()
                         .key('page')
                         .value(page))
            .query_param(Parameter()
                         .key('per_page')
                         .value(per_page))
            .query_param(Parameter()
                         .key('name__icontains')
                         .value(name__icontains))
            .query_param(Parameter()
                         .key('site_id__exact')
                         .value(site_id__exact))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetQueriesResponse.from_dictionary)
        ).execute()

    def create_a_new_query(self,
                           body):
        """Does a POST request to /ranger/queries.

        This route creates a query

        Args:
            body (CreateANewQuery): TODO: type description here.

        Returns:
            CreateANewQueryResponse: Response from the API. Successful
                Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/queries')
            .http_method(HttpMethodEnum.POST)
            .header_param(Parameter()
                          .key('Content-Type')
                          .value('application/json'))
            .body_param(Parameter()
                        .value(body))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(CreateANewQueryResponse.from_dictionary)
        ).execute()

    def delete_a_query(self,
                       content_type):
        """Does a DELETE request to /ranger/queries.

        Delete a query by a list of selected resource IDs

        Args:
            content_type (ContentTypeEnum): TODO: type description here.

        Returns:
            DeleteAQueryResponse: Response from the API. Successful Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/queries')
            .http_method(HttpMethodEnum.DELETE)
            .header_param(Parameter()
                          .key('Content-Type')
                          .value(content_type))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(DeleteAQueryResponse.from_dictionary)
        ).execute()

    def update_a_single_query(self,
                              resource_id,
                              body):
        """Does a POST request to /ranger/queries/{resource_id}.

        This route updates a query

        Args:
            resource_id (string): Resource ID of the query to update
            body (CreateANewQuery): TODO: type description here.

        Returns:
            CreateANewQueryResponse: Response from the API. Successful
                Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/queries/{resource_id}')
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                            .key('resource_id')
                            .value(resource_id)
                            .should_encode(True))
            .header_param(Parameter()
                          .key('Content-Type')
                          .value('application/json'))
            .body_param(Parameter()
                        .value(body))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(CreateANewQueryResponse.from_dictionary)
        ).execute()

    def get_information_for_all_queries(self):
        """Does a GET request to /ranger/queries/get_types.

        Get descriptions and enums for all queries (can be used later to
        retrieve parameters per task type enum)

        Returns:
            object: Response from the API. Successful Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/queries/get_types')
            .http_method(HttpMethodEnum.GET)
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(Object.from_dictionary)
        ).execute()

    def all_queries_fields_types_and_validations(self):
        """Does a GET request to /ranger/queries/get_params.

        This is used to determine the payload needed to be sent for
        creating/updating a query by a certain query type enum value

        Returns:
            object: Response from the API. Successful Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/queries/get_params')
            .http_method(HttpMethodEnum.GET)
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(Object.from_dictionary)
        ).execute()



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper
from ctddocumentation.models.object import Object


class Entity(object):

    """Implementation of the 'Entity' model.

    TODO: type model description here.

    Attributes:
        user_id (string): TODO: type description here.
        mtype (string): TODO: type description here.
        object (object): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "user_id": 'user_id',
        "mtype": 'type',
        "object": 'object'
    }

    _optionals = [
        'user_id',
        'mtype',
        'object',
    ]

    def __init__(self,
                 user_id=APIHelper.SKIP,
                 mtype=APIHelper.SKIP,
                 object=APIHelper.SKIP):
        """Constructor for the Entity class"""

        # Initialize members of the class
        if user_id is not APIHelper.SKIP:
            self.user_id = user_id 
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype 
        if object is not APIHelper.SKIP:
            self.object = object 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        user_id = dictionary.get("user_id") if dictionary.get("user_id") else APIHelper.SKIP
        mtype = dictionary.get("type") if dictionary.get("type") else APIHelper.SKIP
        object = Object.from_dictionary(dictionary.get('object')) if 'object' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(user_id,
                   mtype,
                   object)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper
from ctddocumentation.models.object import Object


class SlimInsight(object):

    """Implementation of the 'SlimInsight' model.

    TODO: type model description here.

    Attributes:
        comment (string): Last comment provided by user
        cve_id (string): The CVE's ID
        cvss (object): The CVE's score
        identified_on (string): The timestamp when the CVE was identified.  
            Format: YYYY-MM-DDTHH:MM:SS (in UTC)
        last_updated (string): The timestamp when the latest change on the CVE
            was made in the EMC.   Format: YYYY-MM-DDTHH:MM:SS+00:00 (in UTC)
        modified (string): The full date of the latest modification was made
            on the CVE by the global provider.   Format: YYYY-MM-DD
        published (string): The full date when the CVE's was published at.  
            Format: YYYY-MM-DD
        status (int): A number that represents the CVE's status.   Options:  0
            - Open  1 - Hidden  2 - Completed
        title (string): The CVE's title

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "comment": 'comment',
        "cve_id": 'cve_id',
        "cvss": 'cvss',
        "identified_on": 'identified_on',
        "last_updated": 'last_updated',
        "modified": 'modified',
        "published": 'published',
        "status": 'status',
        "title": 'title'
    }

    _optionals = [
        'comment',
        'cve_id',
        'cvss',
        'identified_on',
        'last_updated',
        'modified',
        'published',
        'status',
        'title',
    ]

    def __init__(self,
                 comment=APIHelper.SKIP,
                 cve_id=APIHelper.SKIP,
                 cvss=APIHelper.SKIP,
                 identified_on=APIHelper.SKIP,
                 last_updated=APIHelper.SKIP,
                 modified=APIHelper.SKIP,
                 published=APIHelper.SKIP,
                 status=APIHelper.SKIP,
                 title=APIHelper.SKIP):
        """Constructor for the SlimInsight class"""

        # Initialize members of the class
        if comment is not APIHelper.SKIP:
            self.comment = comment 
        if cve_id is not APIHelper.SKIP:
            self.cve_id = cve_id 
        if cvss is not APIHelper.SKIP:
            self.cvss = cvss 
        if identified_on is not APIHelper.SKIP:
            self.identified_on = identified_on 
        if last_updated is not APIHelper.SKIP:
            self.last_updated = last_updated 
        if modified is not APIHelper.SKIP:
            self.modified = modified 
        if published is not APIHelper.SKIP:
            self.published = published 
        if status is not APIHelper.SKIP:
            self.status = status 
        if title is not APIHelper.SKIP:
            self.title = title 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        comment = dictionary.get("comment") if dictionary.get("comment") else APIHelper.SKIP
        cve_id = dictionary.get("cve_id") if dictionary.get("cve_id") else APIHelper.SKIP
        cvss = Object.from_dictionary(dictionary.get('cvss')) if 'cvss' in dictionary.keys() else APIHelper.SKIP
        identified_on = dictionary.get("identified_on") if dictionary.get("identified_on") else APIHelper.SKIP
        last_updated = dictionary.get("last_updated") if dictionary.get("last_updated") else APIHelper.SKIP
        modified = dictionary.get("modified") if dictionary.get("modified") else APIHelper.SKIP
        published = dictionary.get("published") if dictionary.get("published") else APIHelper.SKIP
        status = dictionary.get("status") if dictionary.get("status") else APIHelper.SKIP
        title = dictionary.get("title") if dictionary.get("title") else APIHelper.SKIP
        # Return an object of this model
        return cls(comment,
                   cve_id,
                   cvss,
                   identified_on,
                   last_updated,
                   modified,
                   published,
                   status,
                   title)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from ctddocumentation.api_helper import APIHelper
from ctddocumentation.configuration import Server
from ctddocumentation.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from ctddocumentation.http.http_method_enum import HttpMethodEnum
from apimatic_core.authentication.multiple.single_auth import Single
from apimatic_core.authentication.multiple.and_auth_group import And
from apimatic_core.authentication.multiple.or_auth_group import Or
from ctddocumentation.models.get_assets_response import GetAssetsResponse
from ctddocumentation.models.find_asset_by_id_response import FindAssetByIDResponse
from ctddocumentation.models.assets_with_insights_response import AssetsWithInsightsResponse
from ctddocumentation.exceptions.api_exception import APIException


class AssetsController(BaseController):

    """A Controller to access Endpoints in the ctddocumentation API."""
    def __init__(self, config):
        super(AssetsController, self).__init__(config)

    def get_assets(self,
                   format=None,
                   page=None,
                   per_page=None,
                   ipv_4__exact=None,
                   ipv_6__exact=None,
                   mac__icontains=None,
                   vlan__exact=None,
                   address__exact=None,
                   gateway__exact=None,
                   asset_type__exact=None,
                   host_name__exact=None,
                   os__exact=None,
                   model__icontains=None,
                   vendor__icontains=None,
                   state__exact=None,
                   domain_names__exact=None,
                   firmware__exact=None,
                   serial__exact=None,
                   generic__icontains=None,
                   display_name__icontains=None,
                   criticality__exact=None,
                   old_ip__exact=None,
                   protocol__exact=None,
                   last_seen__exact=None,
                   q__icontains=None,
                   alert_id__exact=None,
                   last_updated__gt=None,
                   baseline__exact=None,
                   arp_baselines__exact=None,
                   insight_status__exact=None,
                   insights_insight_name__exact=None,
                   insight_timestamp__gte=None,
                   insight_timestamp__lte=None,
                   baseline_category__exact=None,
                   baseline_access_type__exact=None,
                   insight_name__exact=None,
                   insight_row_key__exact=None,
                   ghost__exact=None,
                   tasks__exact=None,
                   active_queries__exact=None,
                   subnet_tag__exact=None,
                   custom_attributes__exact=None,
                   class_type__exact=None,
                   domain_name__exact=None,
                   involved_in_tags__exact=None,
                   hosted_tags__icontains=None,
                   id__exact=None,
                   site_id__exact=None,
                   timestamp__exact=None,
                   approved__exact=None,
                   valid__exact=None,
                   parsed__exact=None,
                   special_hint__exact=None,
                   risk_level__exact=None,
                   network_id__exact=None,
                   virtual_zone_id__exact=None,
                   subnet_id__exact=None,
                   purdue_level__exact=None):
        """Does a GET request to /ranger/assets.

        Retrieves a list of assets in CTD, with optional filters.
        Note: All filters are optional.

        Args:
            format (Format1Enum, optional): Specifies the type of response
                (list of fields) returned by the query. If not provided, all
                asset properties are returned and could affect performance.
            page (int, optional): The page number to be viewed
            per_page (int, optional): Number of Assets to pull per page
            ipv_4__exact (string, optional): IP address of the asset in IPv4
                format
            ipv_6__exact (string, optional): IP address of the asset in IPv6
                format
            mac__icontains (string, optional): The MAC address of the device
                (free text)
            vlan__exact (string, optional): The VLAN/s of the device
            address__exact (string, optional): The IP address of this device
                in the network
            gateway__exact (string, optional): IP of the Gateway of the
                Asset's network
            asset_type__exact (string, optional): CTD Asset type, for example
                SCADA client, PLC, etc.
            host_name__exact (string, optional): The host name of this Asset
            os__exact (string, optional): The name of the operating system
            model__icontains (string, optional): The Model of this asset (free
                text)
            vendor__icontains (string, optional): The Vendor of this asset
                (free text)
            state__exact (string, optional): Asset state as selected in the
                dropdown:  0 = Training  1 = Maintenance  2 = Guest
            domain_names__exact (string, optional): The exact domain name(s)
                of the Asset
            firmware__exact (string, optional): The exact firmware name of the
                Asset
            serial__exact (string, optional): The exact serial number of the
                Asset
            generic__icontains (string, optional): Custom information (free
                text)
            display_name__icontains (string, optional): The name of the Asset
                (free text)
            criticality__exact (string, optional): Low, Medium, or High. These
                CTD values represent how critical the asset itself is to the
                operation. CTD assigns criticality automatically to certain
                types of assets but enables you to edit the value.
            old_ip__exact (string, optional): Previous IPs used by this Asset
            protocol__exact (string, optional): List of protocols used by this
                Asset when communicating
            last_seen__exact (string, optional): The timestamp of the last
                instance when this device was seen in the network
            q__icontains (string, optional): Free text for the following Asset
                info: Name, IP, Version, Model and MAC
            alert_id__exact (string, optional): The IDs of the alerts
                triggered by this Asset
            last_updated__gt (string, optional): The timestamp when the latest
                change to the Asset was made in the EMC. **Format:**
                YYYY-MM-DD**T**HH:MM:SS (in UTC) **Example:**
                2022-11-01T16:22:05
            baseline__exact (string, optional): Names of Baselines in which
                the Asset appears
            arp_baselines__exact (string, optional): Whether this asset has
                ARP baselines: True = ARP
            insight_status__exact (InsightStatusExact1Enum, optional): The
                status of the Insight associated with this Asset – this is a
                dropdown for choosing the integer type:  0 = Open  1 = Hidden 
                2 = Completed
            insights_insight_name__exact (string, optional): The name of the
                Insight associated with this Asset
            insight_timestamp__gte (string, optional): When this Insight was
                detected; greater (later) than or equal to a specific
                timestamp
            insight_timestamp__lte (string, optional): When this Insight was
                detected; less (earlier) than or equal to a specific
                timestamp
            baseline_category__exact (string, optional): The category of the
                Baseline of this Asset
            baseline_access_type__exact (string, optional): The access type of
                the Baseline of this asset
            insight_name__exact (string, optional): The name of the Insight
                associated with this Asset
            insight_row_key__exact (string, optional): The row key of the
                related Insight
            ghost__exact (bool, optional): Whether or not this is a ghost
                asset: TRUE = Ghost
            tasks__exact (string, optional): Resource ID of the Active Tasks
                running on this Asset
            active_queries__exact (string, optional): Resource ID of the
                Active Queries running on this Asset
            subnet_tag__exact (string, optional): The device’s network
                location
            custom_attributes__exact (string, optional): The values of the
                (user-defined) Custom Attributes for this Asset
            class_type__exact (string, optional): The class type of this Asset
                (IT, OT, IoT)
            domain_name__exact (string, optional): The domain name of the
                Asset
            involved_in_tags__exact (string, optional): TODO: type description
                here.
            hosted_tags__icontains (string, optional): Artifact name (free
                text)
            id__exact (int, optional): The device’s unique identifier in the
                system
            site_id__exact (int, optional): The identifier of the Site in
                which the device resides
            timestamp__exact (string, optional): The timestamp of when this
                Asset was detected
            approved__exact (bool, optional): If the Asset was approved
            valid__exact (bool, optional): If the Asset is valid: TRUE=valid
            parsed__exact (bool, optional): Whether or not parsed information
                (numerical or textual value from the protocols) was
                incorporated by CTD into the Asset’s baseline
            special_hint__exact (SpecialHintExactEnum, optional): TODO: type
                description here.
            risk_level__exact (int, optional): The CTD level of risk for this
                device, based on its vulnerabilities, insights, alerts,
                policies, asset criticality, and network location
            network_id__exact (int, optional): The ID of the network in which
                this device is located
            virtual_zone_id__exact (int, optional): The group of related
                assets this device belongs to (e.g. PLC Modbus)
            subnet_id__exact (int, optional): The device’s network location
            purdue_level__exact (string, optional): The Purdue model level of
                this specific device (0-6).  This value is automatically
                determined based on the various characteristics of the asset
                and its purpose. Can be adjusted to reflect the true asset
                behavior. Also note that interim Purdue levels can also be
                used, e.g. 1.5, 2.5, 3.5

        Returns:
            GetAssetsResponse: Response from the API. Successful Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/assets')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('format')
                         .value(format))
            .query_param(Parameter()
                         .key('page')
                         .value(page))
            .query_param(Parameter()
                         .key('per_page')
                         .value(per_page))
            .query_param(Parameter()
                         .key('ipv4__exact')
                         .value(ipv_4__exact))
            .query_param(Parameter()
                         .key('ipv6__exact')
                         .value(ipv_6__exact))
            .query_param(Parameter()
                         .key('mac__icontains')
                         .value(mac__icontains))
            .query_param(Parameter()
                         .key('vlan__exact')
                         .value(vlan__exact))
            .query_param(Parameter()
                         .key('address__exact')
                         .value(address__exact))
            .query_param(Parameter()
                         .key('gateway__exact')
                         .value(gateway__exact))
            .query_param(Parameter()
                         .key('asset_type__exact')
                         .value(asset_type__exact))
            .query_param(Parameter()
                         .key('host_name__exact')
                         .value(host_name__exact))
            .query_param(Parameter()
                         .key('os__exact')
                         .value(os__exact))
            .query_param(Parameter()
                         .key('model__icontains')
                         .value(model__icontains))
            .query_param(Parameter()
                         .key('vendor__icontains')
                         .value(vendor__icontains))
            .query_param(Parameter()
                         .key('state__exact')
                         .value(state__exact))
            .query_param(Parameter()
                         .key('domain_names__exact')
                         .value(domain_names__exact))
            .query_param(Parameter()
                         .key('firmware__exact')
                         .value(firmware__exact))
            .query_param(Parameter()
                         .key('serial__exact')
                         .value(serial__exact))
            .query_param(Parameter()
                         .key('generic__icontains')
                         .value(generic__icontains))
            .query_param(Parameter()
                         .key('display_name__icontains')
                         .value(display_name__icontains))
            .query_param(Parameter()
                         .key('criticality__exact')
                         .value(criticality__exact))
            .query_param(Parameter()
                         .key('old_ip__exact')
                         .value(old_ip__exact))
            .query_param(Parameter()
                         .key('protocol__exact')
                         .value(protocol__exact))
            .query_param(Parameter()
                         .key('last_seen__exact')
                         .value(last_seen__exact))
            .query_param(Parameter()
                         .key('q__icontains')
                         .value(q__icontains))
            .query_param(Parameter()
                         .key('alert_id__exact')
                         .value(alert_id__exact))
            .query_param(Parameter()
                         .key('last_updated__gt')
                         .value(last_updated__gt))
            .query_param(Parameter()
                         .key('baseline__exact')
                         .value(baseline__exact))
            .query_param(Parameter()
                         .key('arp_baselines__exact')
                         .value(arp_baselines__exact))
            .query_param(Parameter()
                         .key('insight_status__exact')
                         .value(insight_status__exact))
            .query_param(Parameter()
                         .key('insights_insight_name__exact')
                         .value(insights_insight_name__exact))
            .query_param(Parameter()
                         .key('insight_timestamp__gte')
                         .value(insight_timestamp__gte))
            .query_param(Parameter()
                         .key('insight_timestamp__lte')
                         .value(insight_timestamp__lte))
            .query_param(Parameter()
                         .key('baseline_category__exact')
                         .value(baseline_category__exact))
            .query_param(Parameter()
                         .key('baseline_access_type__exact')
                         .value(baseline_access_type__exact))
            .query_param(Parameter()
                         .key('insight_name__exact')
                         .value(insight_name__exact))
            .query_param(Parameter()
                         .key('insight_row_key__exact')
                         .value(insight_row_key__exact))
            .query_param(Parameter()
                         .key('ghost__exact')
                         .value(ghost__exact))
            .query_param(Parameter()
                         .key('tasks__exact')
                         .value(tasks__exact))
            .query_param(Parameter()
                         .key('active_queries__exact')
                         .value(active_queries__exact))
            .query_param(Parameter()
                         .key('subnet_tag__exact')
                         .value(subnet_tag__exact))
            .query_param(Parameter()
                         .key('custom_attributes__exact')
                         .value(custom_attributes__exact))
            .query_param(Parameter()
                         .key('class_type__exact')
                         .value(class_type__exact))
            .query_param(Parameter()
                         .key('domain_name__exact')
                         .value(domain_name__exact))
            .query_param(Parameter()
                         .key('involved_in_tags__exact')
                         .value(involved_in_tags__exact))
            .query_param(Parameter()
                         .key('hosted_tags__icontains')
                         .value(hosted_tags__icontains))
            .query_param(Parameter()
                         .key('id__exact')
                         .value(id__exact))
            .query_param(Parameter()
                         .key('site_id__exact')
                         .value(site_id__exact))
            .query_param(Parameter()
                         .key('timestamp__exact')
                         .value(timestamp__exact))
            .query_param(Parameter()
                         .key('approved__exact')
                         .value(approved__exact))
            .query_param(Parameter()
                         .key('valid__exact')
                         .value(valid__exact))
            .query_param(Parameter()
                         .key('parsed__exact')
                         .value(parsed__exact))
            .query_param(Parameter()
                         .key('special_hint__exact')
                         .value(special_hint__exact))
            .query_param(Parameter()
                         .key('risk_level__exact')
                         .value(risk_level__exact))
            .query_param(Parameter()
                         .key('network_id__exact')
                         .value(network_id__exact))
            .query_param(Parameter()
                         .key('virtual_zone_id__exact')
                         .value(virtual_zone_id__exact))
            .query_param(Parameter()
                         .key('subnet_id__exact')
                         .value(subnet_id__exact))
            .query_param(Parameter()
                         .key('purdue_level__exact')
                         .value(purdue_level__exact))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetAssetsResponse.from_dictionary)
        ).execute()

    def find_asset_by_id(self,
                         resource_id):
        """Does a GET request to /ranger/assets/{resource_id}.

        Find Asset By ID

        Args:
            resource_id (string): Resource ID of the asset to return

        Returns:
            FindAssetByIDResponse: Response from the API. Successful
                Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/assets/{resource_id}')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('resource_id')
                            .value(resource_id)
                            .should_encode(True))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(FindAssetByIDResponse.from_dictionary)
            .local_error('400', 'Invalid ID supplied', APIException)
            .local_error('404', 'Asset not found', APIException)
        ).execute()

    def get_assetswith_insights(self,
                                page=None,
                                per_page=None,
                                name__exact=None,
                                ghost__exact=None,
                                risk_level__exact=None,
                                site_name__exact=None,
                                network_id__exact=None,
                                ipv_4__exact=None,
                                ipv_6__exact=None,
                                mac__icontains=None,
                                asset_type__exact=None,
                                os__exact=None,
                                model__icontains=None,
                                vendor__icontains=None,
                                firmware__exact=None,
                                criticality__exact=None,
                                insight_cve_id__exact=None,
                                insight_cvss__exact=None,
                                insight_title__contains=None,
                                insight_published__exact=None,
                                insight_modified__exact=None,
                                insight_status__exact=None,
                                insight_identified_on__exact=None,
                                insight_last_updated__exact=None,
                                insight_comment__contains=None):
        """Does a GET request to /ranger/assets_with_insights.

        Returns Assets with the top 10 highest score Insights. 
        **Note:** The used lookups are optional

        Args:
            page (int, optional): The actual page offset
            per_page (int, optional): The max number of items to be included
                in the results
            name__exact (string, optional): Name of the Asset
            ghost__exact (bool, optional): Indicates if the asset has only
                incoming communication, that is, an asset that has never
                replied
            risk_level__exact (int, optional): Calculation of how vulnerable
                this Asset is to attacks
            site_name__exact (string, optional): Name of the Site to which the
                Asset belongs
            network_id__exact (int, optional): ID of the network to which the
                Asset belongs
            ipv_4__exact (string, optional): An IPv4 address that related to
                the Asset
            ipv_6__exact (string, optional): An IPv6 address that related to
                the Asset
            mac__icontains (string, optional): The MAC address of the device
                (free text)
            asset_type__exact (string, optional): CTD Asset type, for example
                SCADA client, PLC, etc.
            os__exact (string, optional): The name of the operating system
                that runs on the Asset
            model__icontains (string, optional): The name of the Asset's
                model
            vendor__icontains (string, optional): The Asset's vendor name
            firmware__exact (string, optional): The Asset's firmware
            criticality__exact (int, optional): How critical the Asset is to
                the overall operation. **Options:** 1 - Low 2 - Medium 3 -
                High
            insight_cve_id__exact (string, optional): The ID number of the CVE
                connected to the Insight
            insight_cvss__exact (float, optional): The CVE's score
            insight_title__contains (string, optional): The CVE's title
            insight_published__exact (string, optional): The full date when
                the CVE's was published: **Format:** YYYY-MM-DD HH:MM:SS
                **Example:** 2016-11-15 06:20:05
            insight_modified__exact (string, optional): The full date of the
                latest modification made to the CVE by the global provider.
                **Format:** YYYY-MM-DD HH:MM:SS **Example:** 2016-11-15
                06:20:05
            insight_status__exact (int, optional): A number that represents
                the CVE's status.   **Options:**   0 - Open  1- Hidden  2 -
                Completed
            insight_identified_on__exact (string, optional): Timestamp when
                the CVE was identified. **Format:** YYYY-MM-DD**T**HH:MM:SS
                (in UTC) **Example:** 2022-11-01T16:22:05
            insight_last_updated__exact (string, optional): Timestamp when the
                latest change to the CVE was made in the EMC. **Format:**
                YYYY-MM-DD**T**HH:MM:SS+00:00 (in UTC) **Example:**
                2022-11-01T16:22:05+00:00
            insight_comment__contains (string, optional): Last comment
                provided by a user

        Returns:
            AssetsWithInsightsResponse: Response from the API. Successful
                Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/assets_with_insights')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('page')
                         .value(page))
            .query_param(Parameter()
                         .key('per_page')
                         .value(per_page))
            .query_param(Parameter()
                         .key('name__exact')
                         .value(name__exact))
            .query_param(Parameter()
                         .key('ghost__exact')
                         .value(ghost__exact))
            .query_param(Parameter()
                         .key('risk_level__exact')
                         .value(risk_level__exact))
            .query_param(Parameter()
                         .key('site_name__exact')
                         .value(site_name__exact))
            .query_param(Parameter()
                         .key('network_id__exact')
                         .value(network_id__exact))
            .query_param(Parameter()
                         .key('ipv4__exact')
                         .value(ipv_4__exact))
            .query_param(Parameter()
                         .key('ipv6__exact')
                         .value(ipv_6__exact))
            .query_param(Parameter()
                         .key('mac__icontains')
                         .value(mac__icontains))
            .query_param(Parameter()
                         .key('asset_type__exact')
                         .value(asset_type__exact))
            .query_param(Parameter()
                         .key('os__exact')
                         .value(os__exact))
            .query_param(Parameter()
                         .key('model__icontains')
                         .value(model__icontains))
            .query_param(Parameter()
                         .key('vendor__icontains')
                         .value(vendor__icontains))
            .query_param(Parameter()
                         .key('firmware__exact')
                         .value(firmware__exact))
            .query_param(Parameter()
                         .key('criticality__exact')
                         .value(criticality__exact))
            .query_param(Parameter()
                         .key('insight_cve_id__exact')
                         .value(insight_cve_id__exact))
            .query_param(Parameter()
                         .key('insight_cvss__exact')
                         .value(insight_cvss__exact))
            .query_param(Parameter()
                         .key('insight_title__contains')
                         .value(insight_title__contains))
            .query_param(Parameter()
                         .key('insight_published__exact')
                         .value(insight_published__exact))
            .query_param(Parameter()
                         .key('insight_modified__exact')
                         .value(insight_modified__exact))
            .query_param(Parameter()
                         .key('insight_status__exact')
                         .value(insight_status__exact))
            .query_param(Parameter()
                         .key('insight_identified_on__exact')
                         .value(insight_identified_on__exact))
            .query_param(Parameter()
                         .key('insight_last_updated__exact')
                         .value(insight_last_updated__exact))
            .query_param(Parameter()
                         .key('insight_comment__contains')
                         .value(insight_comment__contains))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(AssetsWithInsightsResponse.from_dictionary)
        ).execute()



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper


class DiscoveryParams(object):

    """Implementation of the 'DiscoveryParams' model.

    TODO: type model description here.

    Attributes:
        ip_range (string): TODO: type description here.
        sub_query (string): TODO: type description here.
        concurrent_scans (int): TODO: type description here.
        retranmissions (int): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "ip_range": 'ip_range',
        "sub_query": 'sub_query',
        "concurrent_scans": 'concurrent_scans',
        "retranmissions": 'retranmissions'
    }

    _optionals = [
        'ip_range',
        'sub_query',
        'concurrent_scans',
        'retranmissions',
    ]

    def __init__(self,
                 ip_range=APIHelper.SKIP,
                 sub_query=APIHelper.SKIP,
                 concurrent_scans=APIHelper.SKIP,
                 retranmissions=APIHelper.SKIP):
        """Constructor for the DiscoveryParams class"""

        # Initialize members of the class
        if ip_range is not APIHelper.SKIP:
            self.ip_range = ip_range 
        if sub_query is not APIHelper.SKIP:
            self.sub_query = sub_query 
        if concurrent_scans is not APIHelper.SKIP:
            self.concurrent_scans = concurrent_scans 
        if retranmissions is not APIHelper.SKIP:
            self.retranmissions = retranmissions 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        ip_range = dictionary.get("ip_range") if dictionary.get("ip_range") else APIHelper.SKIP
        sub_query = dictionary.get("sub_query") if dictionary.get("sub_query") else APIHelper.SKIP
        concurrent_scans = dictionary.get("concurrent_scans") if dictionary.get("concurrent_scans") else APIHelper.SKIP
        retranmissions = dictionary.get("retranmissions") if dictionary.get("retranmissions") else APIHelper.SKIP
        # Return an object of this model
        return cls(ip_range,
                   sub_query,
                   concurrent_scans,
                   retranmissions)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Format1Enum(object):

    """Implementation of the 'format1' enum.

    Specifies the type of response (list of fields) returned by the query. 
    If not provided, all asset's properties will return and could affect
    performance.

    Attributes:
        ASSET_LIST: TODO: type description here.
        INSIGHT_ASSETS: TODO: type description here.
        RIDS: TODO: type description here.

    """

    ASSET_LIST = 'asset_list'

    INSIGHT_ASSETS = 'insight_assets'

    RIDS = 'rids'



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Sort1Enum(object):

    """Implementation of the 'sort1' enum.

    TODO: type enum description here.

    Attributes:
        NAME: TODO: type description here.
        ENUM_NAME: TODO: type description here.
        STATUS: TODO: type description here.
        ENUM_STATUS: TODO: type description here.
        ENABLED: TODO: type description here.
        ENUM_ENABLED: TODO: type description here.
        INTERVAL: TODO: type description here.
        ENUM_INTERVAL: TODO: type description here.
        START_TIME: TODO: type description here.
        ENUM_START_TIME: TODO: type description here.
        END_TIME: TODO: type description here.
        ENUM_END_TIME: TODO: type description here.
        ALLOWED_RUN_TIME_START: TODO: type description here.
        ENUM_ALLOWED_RUN_TIME_START: TODO: type description here.
        ALLOWED_RUN_TIME_END: TODO: type description here.
        ENUM_ALLOWED_RUN_TIME_END: TODO: type description here.
        LAST_RUN_RESULTS: TODO: type description here.
        ENUM_LAST_RUN_RESULTS: TODO: type description here.

    """

    NAME = 'name'

    ENUM_NAME = '-name'

    STATUS = 'status'

    ENUM_STATUS = '-status'

    ENABLED = 'enabled'

    ENUM_ENABLED = '-enabled'

    INTERVAL = 'interval'

    ENUM_INTERVAL = '-interval'

    START_TIME = 'start_time'

    ENUM_START_TIME = '-start_time'

    END_TIME = 'end_time'

    ENUM_END_TIME = '-end_time'

    ALLOWED_RUN_TIME_START = 'allowed_run_time_start'

    ENUM_ALLOWED_RUN_TIME_START = '-allowed_run_time_start'

    ALLOWED_RUN_TIME_END = 'allowed_run_time_end'

    ENUM_ALLOWED_RUN_TIME_END = '-allowed_run_time_end'

    LAST_RUN_RESULTS = 'last_run_results'

    ENUM_LAST_RUN_RESULTS = '-last_run_results'



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper


class Cap(object):

    """Implementation of the 'Cap' model.

    TODO: type model description here.

    Attributes:
        site_id (int): TODO: type description here.
        resource_id (string): TODO: type description here.
        id (int): TODO: type description here.
        deleted (bool): TODO: type description here.
        file_name (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "site_id": 'site_id',
        "resource_id": 'resource_id',
        "id": 'id',
        "deleted": 'deleted',
        "file_name": 'file_name'
    }

    _optionals = [
        'site_id',
        'resource_id',
        'id',
        'deleted',
        'file_name',
    ]

    def __init__(self,
                 site_id=APIHelper.SKIP,
                 resource_id=APIHelper.SKIP,
                 id=APIHelper.SKIP,
                 deleted=APIHelper.SKIP,
                 file_name=APIHelper.SKIP):
        """Constructor for the Cap class"""

        # Initialize members of the class
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id 
        if resource_id is not APIHelper.SKIP:
            self.resource_id = resource_id 
        if id is not APIHelper.SKIP:
            self.id = id 
        if deleted is not APIHelper.SKIP:
            self.deleted = deleted 
        if file_name is not APIHelper.SKIP:
            self.file_name = file_name 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        site_id = dictionary.get("site_id") if dictionary.get("site_id") else APIHelper.SKIP
        resource_id = dictionary.get("resource_id") if dictionary.get("resource_id") else APIHelper.SKIP
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        deleted = dictionary.get("deleted") if "deleted" in dictionary.keys() else APIHelper.SKIP
        file_name = dictionary.get("file_name") if dictionary.get("file_name") else APIHelper.SKIP
        # Return an object of this model
        return cls(site_id,
                   resource_id,
                   id,
                   deleted,
                   file_name)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper


class Group(object):

    """Implementation of the 'Group' model.

    TODO: type model description here.

    Attributes:
        name (string): TODO: type description here.
        is_admin (bool): TODO: type description here.
        associated_external_groups (list of string): TODO: type description
            here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "is_admin": 'is_admin',
        "associated_external_groups": 'associated_external_groups'
    }

    _optionals = [
        'is_admin',
        'associated_external_groups',
    ]

    def __init__(self,
                 name=None,
                 is_admin=APIHelper.SKIP,
                 associated_external_groups=APIHelper.SKIP):
        """Constructor for the Group class"""

        # Initialize members of the class
        self.name = name 
        if is_admin is not APIHelper.SKIP:
            self.is_admin = is_admin 
        if associated_external_groups is not APIHelper.SKIP:
            self.associated_external_groups = associated_external_groups 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        name = dictionary.get("name") if dictionary.get("name") else None
        is_admin = dictionary.get("is_admin") if "is_admin" in dictionary.keys() else APIHelper.SKIP
        associated_external_groups = dictionary.get("associated_external_groups") if dictionary.get("associated_external_groups") else APIHelper.SKIP
        # Return an object of this model
        return cls(name,
                   is_admin,
                   associated_external_groups)



__all__ = [
    'paginated_response',
    'alert',
    'asset',
    'assets_with_insights_response',
    'assets_with_insights',
    'activity',
    'subnet',
    'network',
    'policy',
    'actionable',
    'actionable_cap',
    'actionable_policy',
    'actionable_information',
    'actionable_asset',
    'identifiable',
    'code_sections',
    'indicators',
    'site',
    'base_task',
    'task',
    'new_queryobject',
    'new_taskobject',
    'taskextraparams',
    'queryextraparams',
    'active_history',
    'event',
    'custom_attribute_category',
    'add_license_response',
    'actionable_related_asset',
    'authenticate',
    'createanewtask',
    'create_a_new_query',
    'selection_params',
    'license_request',
    'user',
    'group',
    'cap',
    'create_a_new_query_response',
    'createanewtask_response',
    'create_group_response',
    'create_user_response',
    'ctd_login_exception',
    'ctd_login_response',
    'db_statistics',
    'delete_a_query_response',
    'delete_a_task_response',
    'destination_virtual_zone',
    'detail',
    'discovery_params',
    'entity',
    'find_asset_by_id_response',
    'get_active_detection_history_response',
    'get_alerts_response',
    'get_all_sites_response',
    'get_assets_response',
    'get_custom_attribute_categories_response',
    'get_events_response',
    'get_license_details_response',
    'get_queries_response',
    'get_tasks_response',
    'indicator_info',
    'information',
    'get_queries_ids_and_assigned_task_response',
    'object',
    'activities_object',
    'activities_response',
    'risk_vector',
    'selection_params_1',
    'source_virtual_zone',
    'update_a_single_query_response',
    'update_a_single_task_response',
    'get_types_response',
    'update_license_response',
    'virtual_zones',
    'ranger_system_check_response',
    'slim_insight',
    'alert_severity_enum',
    'special_hint_enum',
    'insight_status_enum',
    'format_enum',
    'site_list_slim_enum',
    'insight_status_exact_enum',
    'sort_enum',
    'sort_1_enum',
    'sort_3_enum',
    'sort_4_enum',
    'sort_5_enum',
    'sort_6_enum',
    'special_hint_exact_enum',
    'status_enum',
    'status_exact_enum',
    'content_type_enum',
    'format_1_enum',
    'sort_31_enum',
    'sort_41_enum',
    'insight_status_exact_1_enum',
]



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper
from ctddocumentation.models.cap import Cap


class ActionableCap(object):

    """Implementation of the 'ActionableCap' model.

    TODO: type model description here.

    Attributes:
        actionable_id (int): TODO: type description here.
        role_number (int): TODO: type description here.
        role_name (string): TODO: type description here.
        cap (Cap): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "actionable_id": 'actionable_id',
        "role_number": 'role_number',
        "role_name": 'role_name',
        "cap": 'cap'
    }

    _optionals = [
        'actionable_id',
        'role_number',
        'role_name',
        'cap',
    ]

    def __init__(self,
                 actionable_id=APIHelper.SKIP,
                 role_number=APIHelper.SKIP,
                 role_name=APIHelper.SKIP,
                 cap=APIHelper.SKIP):
        """Constructor for the ActionableCap class"""

        # Initialize members of the class
        if actionable_id is not APIHelper.SKIP:
            self.actionable_id = actionable_id 
        if role_number is not APIHelper.SKIP:
            self.role_number = role_number 
        if role_name is not APIHelper.SKIP:
            self.role_name = role_name 
        if cap is not APIHelper.SKIP:
            self.cap = cap 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        actionable_id = dictionary.get("actionable_id") if dictionary.get("actionable_id") else APIHelper.SKIP
        role_number = dictionary.get("role_number") if dictionary.get("role_number") else APIHelper.SKIP
        role_name = dictionary.get("role_name") if dictionary.get("role_name") else APIHelper.SKIP
        cap = Cap.from_dictionary(dictionary.get('cap')) if 'cap' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(actionable_id,
                   role_number,
                   role_name,
                   cap)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from ctddocumentation.api_helper import APIHelper
from ctddocumentation.configuration import Server
from ctddocumentation.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from ctddocumentation.http.http_method_enum import HttpMethodEnum
from apimatic_core.authentication.multiple.single_auth import Single
from apimatic_core.authentication.multiple.and_auth_group import And
from apimatic_core.authentication.multiple.or_auth_group import Or
from ctddocumentation.models.get_queries_response import GetQueriesResponse
from ctddocumentation.models.create_a_new_query_response import CreateANewQueryResponse
from ctddocumentation.models.delete_a_query_response import DeleteAQueryResponse
from ctddocumentation.models.object import Object
from ctddocumentation.models.get_active_detection_history_response import GetActiveDetectionHistoryResponse


class TasksController(BaseController):

    """A Controller to access Endpoints in the ctddocumentation API."""
    def __init__(self, config):
        super(TasksController, self).__init__(config)

    def get_tasks(self,
                  sort=None,
                  page=1,
                  per_page=20,
                  name__icontains=None,
                  site_id__exact=None):
        """Does a GET request to /ranger/scans.

        Get all tasks and their information

        Args:
            sort (Sort1Enum, optional): TODO: type description here.
            page (int, optional): TODO: type description here. Example: 1
            per_page (int, optional): TODO: type description here. Example:
                20
            name__icontains (string, optional): TODO: type description here.
            site_id__exact (int, optional): TODO: type description here.

        Returns:
            GetQueriesResponse: Response from the API. Successful Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/scans')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('sort')
                         .value(sort))
            .query_param(Parameter()
                         .key('page')
                         .value(page))
            .query_param(Parameter()
                         .key('per_page')
                         .value(per_page))
            .query_param(Parameter()
                         .key('name__icontains')
                         .value(name__icontains))
            .query_param(Parameter()
                         .key('site_id__exact')
                         .value(site_id__exact))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetQueriesResponse.from_dictionary)
        ).execute()

    def create_a_new_task(self,
                          body):
        """Does a POST request to /ranger/scans.

        This route creates a task

        Args:
            body (Createanewtask): TODO: type description here.

        Returns:
            CreateANewQueryResponse: Response from the API. Successful
                Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/scans')
            .http_method(HttpMethodEnum.POST)
            .header_param(Parameter()
                          .key('Content-Type')
                          .value('application/json'))
            .body_param(Parameter()
                        .value(body))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(CreateANewQueryResponse.from_dictionary)
        ).execute()

    def delete_a_task(self,
                      content_type):
        """Does a DELETE request to /ranger/scans.

        Delete a task by a list of selected resource IDs

        Args:
            content_type (ContentTypeEnum): TODO: type description here.

        Returns:
            DeleteAQueryResponse: Response from the API. Successful Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/scans')
            .http_method(HttpMethodEnum.DELETE)
            .header_param(Parameter()
                          .key('Content-Type')
                          .value(content_type))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(DeleteAQueryResponse.from_dictionary)
        ).execute()

    def update_a_single_task(self,
                             resource_id,
                             body):
        """Does a POST request to /ranger/scans/{resource_id}.

        This route updates a task

        Args:
            resource_id (string): Resource ID of the task to update
            body (Createanewtask): TODO: type description here.

        Returns:
            CreateANewQueryResponse: Response from the API. Successful
                Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/scans/{resource_id}')
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                            .key('resource_id')
                            .value(resource_id)
                            .should_encode(True))
            .header_param(Parameter()
                          .key('Content-Type')
                          .value('application/json'))
            .body_param(Parameter()
                        .value(body))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(CreateANewQueryResponse.from_dictionary)
        ).execute()

    def information_of_all_tasks(self):
        """Does a GET request to /ranger/scans/get_types.

        Get descriptions and enums for all tasks (can be used later to
        retrieve parameters per task type enum)

        Returns:
            dict: Response from the API. Successful Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/scans/get_types')
            .http_method(HttpMethodEnum.GET)
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(Object.from_dictionary)
        ).execute()

    def all_tasks_fields(self):
        """Does a GET request to /ranger/scans/get_params.

        This is used to determine the payload needed to be sent for
        creating/updating a task by a certain task type enum value

        Returns:
            dict: Response from the API. Successful Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/scans/get_params')
            .http_method(HttpMethodEnum.GET)
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(Object.from_dictionary)
        ).execute()

    def get_active_detection_history(self,
                                     site_id__exact,
                                     sort=None):
        """Does a GET request to /ranger/active_history.

        Get active detection history

        Args:
            site_id__exact (int): TODO: type description here.
            sort (string, optional): TODO: type description here.

        Returns:
            GetActiveDetectionHistoryResponse: Response from the API.
                Successful Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/active_history')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('site_id__exact')
                         .value(site_id__exact))
            .query_param(Parameter()
                         .key('sort')
                         .value(sort))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetActiveDetectionHistoryResponse.from_dictionary)
        ).execute()



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper
from ctddocumentation.models.code_sections import CodeSections


class Information(object):

    """Implementation of the 'Information' model.

    TODO: type model description here.

    Attributes:
        site_id (int): TODO: type description here.
        resource_id (string): TODO: type description here.
        id (int): TODO: type description here.
        asset_id (int): TODO: type description here.
        code_sections (list of CodeSections): TODO: type description here.
        source (string): TODO: type description here.
        originator_name (string): TODO: type description here.
        originator_number (int): TODO: type description here.
        information_type_name (string): TODO: type description here.
        information_type_number (int): TODO: type description here.
        approved (bool): TODO: type description here.
        valid (bool): TODO: type description here.
        timestamp (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "site_id": 'site_id',
        "resource_id": 'resource_id',
        "id": 'id',
        "asset_id": 'asset_id',
        "code_sections": 'code_sections',
        "source": 'source',
        "originator_name": 'originator_name',
        "originator_number": 'originator_number',
        "information_type_name": 'information_type_name',
        "information_type_number": 'information_type_number',
        "approved": 'approved',
        "valid": 'valid',
        "timestamp": 'timestamp'
    }

    _optionals = [
        'site_id',
        'resource_id',
        'id',
        'asset_id',
        'code_sections',
        'source',
        'originator_name',
        'originator_number',
        'information_type_name',
        'information_type_number',
        'approved',
        'valid',
        'timestamp',
    ]

    def __init__(self,
                 site_id=APIHelper.SKIP,
                 resource_id=APIHelper.SKIP,
                 id=APIHelper.SKIP,
                 asset_id=APIHelper.SKIP,
                 code_sections=APIHelper.SKIP,
                 source=APIHelper.SKIP,
                 originator_name=APIHelper.SKIP,
                 originator_number=APIHelper.SKIP,
                 information_type_name=APIHelper.SKIP,
                 information_type_number=APIHelper.SKIP,
                 approved=APIHelper.SKIP,
                 valid=APIHelper.SKIP,
                 timestamp=APIHelper.SKIP):
        """Constructor for the Information class"""

        # Initialize members of the class
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id 
        if resource_id is not APIHelper.SKIP:
            self.resource_id = resource_id 
        if id is not APIHelper.SKIP:
            self.id = id 
        if asset_id is not APIHelper.SKIP:
            self.asset_id = asset_id 
        if code_sections is not APIHelper.SKIP:
            self.code_sections = code_sections 
        if source is not APIHelper.SKIP:
            self.source = source 
        if originator_name is not APIHelper.SKIP:
            self.originator_name = originator_name 
        if originator_number is not APIHelper.SKIP:
            self.originator_number = originator_number 
        if information_type_name is not APIHelper.SKIP:
            self.information_type_name = information_type_name 
        if information_type_number is not APIHelper.SKIP:
            self.information_type_number = information_type_number 
        if approved is not APIHelper.SKIP:
            self.approved = approved 
        if valid is not APIHelper.SKIP:
            self.valid = valid 
        if timestamp is not APIHelper.SKIP:
            self.timestamp = timestamp 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        site_id = dictionary.get("site_id") if dictionary.get("site_id") else APIHelper.SKIP
        resource_id = dictionary.get("resource_id") if dictionary.get("resource_id") else APIHelper.SKIP
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        asset_id = dictionary.get("asset_id") if dictionary.get("asset_id") else APIHelper.SKIP
        code_sections = None
        if dictionary.get('code_sections') is not None:
            code_sections = [CodeSections.from_dictionary(x) for x in dictionary.get('code_sections')]
        else:
            code_sections = APIHelper.SKIP
        source = dictionary.get("source") if dictionary.get("source") else APIHelper.SKIP
        originator_name = dictionary.get("originator_name") if dictionary.get("originator_name") else APIHelper.SKIP
        originator_number = dictionary.get("originator_number") if dictionary.get("originator_number") else APIHelper.SKIP
        information_type_name = dictionary.get("information_type_name") if dictionary.get("information_type_name") else APIHelper.SKIP
        information_type_number = dictionary.get("information_type_number") if dictionary.get("information_type_number") else APIHelper.SKIP
        approved = dictionary.get("approved") if "approved" in dictionary.keys() else APIHelper.SKIP
        valid = dictionary.get("valid") if "valid" in dictionary.keys() else APIHelper.SKIP
        timestamp = dictionary.get("timestamp") if dictionary.get("timestamp") else APIHelper.SKIP
        # Return an object of this model
        return cls(site_id,
                   resource_id,
                   id,
                   asset_id,
                   code_sections,
                   source,
                   originator_name,
                   originator_number,
                   information_type_name,
                   information_type_number,
                   approved,
                   valid,
                   timestamp)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper


class Event(object):

    """Implementation of the 'Event' model.

    TODO: type model description here.

    Attributes:
        resource_id (string): TODO: type description here.
        id (int): TODO: type description here.
        site_id (int): TODO: type description here.
        timestamp (string): TODO: type description here.
        last_updated (string): TODO: type description here.
        type_number (int): 0: eNewAsset | 1: eAssetConflict | 2:
            eBaselineDeviation | 3: eThreat | 4: eAssetInformationChange | 5:
            eProtocolSpecific  6: eBaselineDown | 8:
            eBaselineVolumeDeviationHigh | 9: eBaselineVolumeDeviationLow |
            10: eFTPData  11: eBaselineRule | 12: eHighArpActivity | 13:
            eKnownThreatEvent | 14: eFalseMac | 15: eSuspiciousFileTransfer 
            16: ePolicyViolation | 17: ePolicyRuleMatch | 18: eHostScan | 19:
            ePortScan | 20: eDenialOfService
        description (string): TODO: type description here.
        alert_id (int): TODO: type description here.
        status (string): TODO: type description here.
        type_name (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "resource_id": 'resource_id',
        "id": 'id',
        "site_id": 'site_id',
        "timestamp": 'timestamp',
        "last_updated": 'last_updated',
        "type_number": 'type_number',
        "description": 'description',
        "alert_id": 'alert_id',
        "status": 'status',
        "type_name": 'type_name'
    }

    _optionals = [
        'resource_id',
        'id',
        'site_id',
        'timestamp',
        'last_updated',
        'type_number',
        'description',
        'alert_id',
        'status',
        'type_name',
    ]

    def __init__(self,
                 resource_id=APIHelper.SKIP,
                 id=APIHelper.SKIP,
                 site_id=APIHelper.SKIP,
                 timestamp=APIHelper.SKIP,
                 last_updated=APIHelper.SKIP,
                 type_number=APIHelper.SKIP,
                 description=APIHelper.SKIP,
                 alert_id=APIHelper.SKIP,
                 status=APIHelper.SKIP,
                 type_name=APIHelper.SKIP):
        """Constructor for the Event class"""

        # Initialize members of the class
        if resource_id is not APIHelper.SKIP:
            self.resource_id = resource_id 
        if id is not APIHelper.SKIP:
            self.id = id 
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id 
        if timestamp is not APIHelper.SKIP:
            self.timestamp = timestamp 
        if last_updated is not APIHelper.SKIP:
            self.last_updated = last_updated 
        if type_number is not APIHelper.SKIP:
            self.type_number = type_number 
        if description is not APIHelper.SKIP:
            self.description = description 
        if alert_id is not APIHelper.SKIP:
            self.alert_id = alert_id 
        if status is not APIHelper.SKIP:
            self.status = status 
        if type_name is not APIHelper.SKIP:
            self.type_name = type_name 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        resource_id = dictionary.get("resource_id") if dictionary.get("resource_id") else APIHelper.SKIP
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        site_id = dictionary.get("site_id") if dictionary.get("site_id") else APIHelper.SKIP
        timestamp = dictionary.get("timestamp") if dictionary.get("timestamp") else APIHelper.SKIP
        last_updated = dictionary.get("last_updated") if dictionary.get("last_updated") else APIHelper.SKIP
        type_number = dictionary.get("type_number") if dictionary.get("type_number") else APIHelper.SKIP
        description = dictionary.get("description") if dictionary.get("description") else APIHelper.SKIP
        alert_id = dictionary.get("alert_id") if dictionary.get("alert_id") else APIHelper.SKIP
        status = dictionary.get("status") if dictionary.get("status") else APIHelper.SKIP
        type_name = dictionary.get("type_name") if dictionary.get("type_name") else APIHelper.SKIP
        # Return an object of this model
        return cls(resource_id,
                   id,
                   site_id,
                   timestamp,
                   last_updated,
                   type_number,
                   description,
                   alert_id,
                   status,
                   type_name)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from ctddocumentation.api_helper import APIHelper
from ctddocumentation.configuration import Server
from ctddocumentation.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from ctddocumentation.http.http_method_enum import HttpMethodEnum
from apimatic_core.authentication.multiple.single_auth import Single
from apimatic_core.authentication.multiple.and_auth_group import And
from apimatic_core.authentication.multiple.or_auth_group import Or
from ctddocumentation.models.get_alerts_response import GetAlertsResponse
from ctddocumentation.models.alert import Alert


class AlertsController(BaseController):

    """A Controller to access Endpoints in the ctddocumentation API."""
    def __init__(self, config):
        super(AlertsController, self).__init__(config)

    def get_alerts(self,
                   page=None,
                   per_page=None,
                   asset_id__exact=None,
                   asset__exact=None,
                   for_asset__exact=None,
                   q__exact=None,
                   primary_asset__exact=None,
                   non_primary_assets__exact=None,
                   virtual_zone__exact=None,
                   alert_id__exact=None,
                   ot_alerts__exact=None,
                   family__exact=None,
                   story_severity__exact=None,
                   id__exact=None,
                   site_id__exact=None,
                   data__exact=None,
                   description__exact=None,
                   type__exact=None,
                   category__exact=None,
                   severity__exact=None,
                   timestamp__exact=None,
                   last_updated__gte=None,
                   relevant__exact=None,
                   resolved__exact=None,
                   resolution__exact=None,
                   protocol__exact=None,
                   score__exact=None,
                   is_qualified__exact=None,
                   network_id__exact=None,
                   resolved_id__exact=None,
                   assigned_id__exact=None,
                   story_id__exact=None,
                   sort=None):
        """Does a GET request to /ranger/alerts.

        Retrieves a list of Alerts in CTD, with optional filters.
        Note - All filters are optional.

        Args:
            page (int, optional): Page offset
            per_page (int, optional): Number of Alerts to pull on each page.
                (The maximum is 500).
            asset_id__exact (string, optional): Resource ID of the Asset
            asset__exact (string, optional): TODO: type description here.
            for_asset__exact (string, optional): TODO: type description here.
            q__exact (string, optional): TODO: type description here.
            primary_asset__exact (string, optional): The resource ID of the
                primary asset that triggered the alert
            non_primary_assets__exact (string, optional): Resource IDs of the
                non-primary assets involved in the alert
            virtual_zone__exact (string, optional): The resource ID of the
                Zone that triggered the alert
            alert_id__exact (string, optional): The resource ID of the Alert. 
                You can add multiple IDs.
            ot_alerts__exact (string, optional): TODO: type description here.
            family__exact (string, optional): Model family of the Asset
                involved in the Alert, for example Policy Violation. Alert
                Families appear in the Advanced Options filter of Alerts.
            story_severity__exact (string, optional): TODO: type description
                here.
            id__exact (int, optional): TODO: type description here.
            site_id__exact (int, optional): ID of the Site on which the Alert
                occurred
            data__exact (string, optional): TODO: type description here.
            description__exact (string, optional): Description of the alert
            type__exact (int, optional): Alert Type, such as Known Threat, New
                Conflict Asset, etc.
            category__exact (int, optional): Alert Category: 0 = Integrity, 1
                = Security
            severity__exact (int, optional): Alert Severity: 0 = Low, 1 =
                Medium, 2 = High, 3 = Critical
            timestamp__exact (string, optional): Timestamp on which the Alert
                occured. **Format:** YYYY-MM-DD**T**HH:MM:SS (in UTC)
                **Example:** 2022-11-01T16:22:05
            last_updated__gte (string, optional): The timestamp when the
                latest change on the Alert was made in the EMC.   **Format:**
                YYYY-MM-DD**T**HH:MM:SS (in UTC)  **Example:**
                2022-11-01T16:22:05
            relevant__exact (bool, optional): TODO: type description here.
            resolved__exact (bool, optional): Whether or not an Alert was
                resolved: True = resolved, False = not resolved
            resolution__exact (int, optional): Type of resolution.
            protocol__exact (string, optional): Protocol used in the alert,
                for example: S7Comm
            score__exact (int, optional): Alert Score calculated for this
                alert, on a score of 1-100
            is_qualified__exact (bool, optional): TODO: type description
                here.
            network_id__exact (int, optional): TODO: type description here.
            resolved_id__exact (int, optional): TODO: type description here.
            assigned_id__exact (int, optional): ID of the User to which the
                Alert was assigned
            story_id__exact (int, optional): ID of the Alert Story to which
                the Alert belongs - can be viewed in the UI by selecting
                "Group By Story"
            sort (SortEnum, optional): By default, results are sorted in
                ascending order of the sort attribute. The sorting prefix "-"
                sorts the results in descending order of the sort attribute.

        Returns:
            GetAlertsResponse: Response from the API. Successful Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/alerts')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('page')
                         .value(page))
            .query_param(Parameter()
                         .key('per_page')
                         .value(per_page))
            .query_param(Parameter()
                         .key('asset_id__exact')
                         .value(asset_id__exact))
            .query_param(Parameter()
                         .key('asset__exact')
                         .value(asset__exact))
            .query_param(Parameter()
                         .key('for_asset__exact')
                         .value(for_asset__exact))
            .query_param(Parameter()
                         .key('q__exact')
                         .value(q__exact))
            .query_param(Parameter()
                         .key('primary_asset__exact')
                         .value(primary_asset__exact))
            .query_param(Parameter()
                         .key('non_primary_assets__exact')
                         .value(non_primary_assets__exact))
            .query_param(Parameter()
                         .key('virtual_zone__exact')
                         .value(virtual_zone__exact))
            .query_param(Parameter()
                         .key('alert_id__exact')
                         .value(alert_id__exact))
            .query_param(Parameter()
                         .key('ot_alerts__exact')
                         .value(ot_alerts__exact))
            .query_param(Parameter()
                         .key('family__exact')
                         .value(family__exact))
            .query_param(Parameter()
                         .key('story_severity__exact')
                         .value(story_severity__exact))
            .query_param(Parameter()
                         .key('id__exact')
                         .value(id__exact))
            .query_param(Parameter()
                         .key('site_id__exact')
                         .value(site_id__exact))
            .query_param(Parameter()
                         .key('data__exact')
                         .value(data__exact))
            .query_param(Parameter()
                         .key('description__exact')
                         .value(description__exact))
            .query_param(Parameter()
                         .key('type__exact')
                         .value(type__exact))
            .query_param(Parameter()
                         .key('category__exact')
                         .value(category__exact))
            .query_param(Parameter()
                         .key('severity__exact')
                         .value(severity__exact))
            .query_param(Parameter()
                         .key('timestamp__exact')
                         .value(timestamp__exact))
            .query_param(Parameter()
                         .key('last_updated__gte')
                         .value(last_updated__gte))
            .query_param(Parameter()
                         .key('relevant__exact')
                         .value(relevant__exact))
            .query_param(Parameter()
                         .key('resolved__exact')
                         .value(resolved__exact))
            .query_param(Parameter()
                         .key('resolution__exact')
                         .value(resolution__exact))
            .query_param(Parameter()
                         .key('protocol__exact')
                         .value(protocol__exact))
            .query_param(Parameter()
                         .key('score__exact')
                         .value(score__exact))
            .query_param(Parameter()
                         .key('is_qualified__exact')
                         .value(is_qualified__exact))
            .query_param(Parameter()
                         .key('network_id__exact')
                         .value(network_id__exact))
            .query_param(Parameter()
                         .key('resolved_id__exact')
                         .value(resolved_id__exact))
            .query_param(Parameter()
                         .key('assigned_id__exact')
                         .value(assigned_id__exact))
            .query_param(Parameter()
                         .key('story_id__exact')
                         .value(story_id__exact))
            .query_param(Parameter()
                         .key('sort')
                         .value(sort))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetAlertsResponse.from_dictionary)
        ).execute()

    def find_alert_by_id(self,
                         resource_id):
        """Does a GET request to /ranger/alerts/{resource_id}.

        Get a single alert.

        Args:
            resource_id (string): Resource ID of the Alert to return

        Returns:
            Alert: Response from the API. Successful Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/alerts/{resource_id}')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('resource_id')
                            .value(resource_id)
                            .should_encode(True))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(Alert.from_dictionary)
        ).execute()



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper


class DestinationVirtualZone(object):

    """Implementation of the 'DestinationVirtualZone' model.

    TODO: type model description here.

    Attributes:
        name (string): TODO: type description here.
        num_assets (int): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "num_assets": 'num_assets'
    }

    _optionals = [
        'name',
        'num_assets',
    ]

    def __init__(self,
                 name=APIHelper.SKIP,
                 num_assets=APIHelper.SKIP):
        """Constructor for the DestinationVirtualZone class"""

        # Initialize members of the class
        if name is not APIHelper.SKIP:
            self.name = name 
        if num_assets is not APIHelper.SKIP:
            self.num_assets = num_assets 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        num_assets = dictionary.get("num_assets") if dictionary.get("num_assets") else APIHelper.SKIP
        # Return an object of this model
        return cls(name,
                   num_assets)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper
from ctddocumentation.models.assets_with_insights import AssetsWithInsights


class AssetsWithInsightsResponse(object):

    """Implementation of the 'AssetsWithInsightsResponse' model.

    TODO: type model description here.

    Attributes:
        count_filtered (int): TODO: type description here.
        count_in_page (int): TODO: type description here.
        count_total (int): TODO: type description here.
        objects (list of AssetsWithInsights): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "count_filtered": 'count_filtered',
        "count_in_page": 'count_in_page',
        "count_total": 'count_total',
        "objects": 'objects'
    }

    _optionals = [
        'count_filtered',
        'count_in_page',
        'count_total',
        'objects',
    ]

    def __init__(self,
                 count_filtered=APIHelper.SKIP,
                 count_in_page=APIHelper.SKIP,
                 count_total=APIHelper.SKIP,
                 objects=APIHelper.SKIP):
        """Constructor for the AssetsWithInsightsResponse class"""

        # Initialize members of the class
        if count_filtered is not APIHelper.SKIP:
            self.count_filtered = count_filtered 
        if count_in_page is not APIHelper.SKIP:
            self.count_in_page = count_in_page 
        if count_total is not APIHelper.SKIP:
            self.count_total = count_total 
        if objects is not APIHelper.SKIP:
            self.objects = objects 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        count_filtered = dictionary.get("count_filtered") if dictionary.get("count_filtered") else APIHelper.SKIP
        count_in_page = dictionary.get("count_in_page") if dictionary.get("count_in_page") else APIHelper.SKIP
        count_total = dictionary.get("count_total") if dictionary.get("count_total") else APIHelper.SKIP
        objects = None
        if dictionary.get('objects') is not None:
            objects = [AssetsWithInsights.from_dictionary(x) for x in dictionary.get('objects')]
        else:
            objects = APIHelper.SKIP
        # Return an object of this model
        return cls(count_filtered,
                   count_in_page,
                   count_total,
                   objects)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper
from ctddocumentation.models.destination_virtual_zone import DestinationVirtualZone


class VirtualZones(object):

    """Implementation of the 'VirtualZones' model.

    TODO: type model description here.

    Attributes:
        destination_virtual_zone (DestinationVirtualZone): TODO: type
            description here.
        source_virtual_zone (DestinationVirtualZone): TODO: type description
            here.
        destination_virtual_zone_id (int): TODO: type description here.
        source_virtual_zone_id (int): TODO: type description here.
        policy_id (int): TODO: type description here.
        id (int): TODO: type description here.
        site_id (int): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "destination_virtual_zone": 'destination_virtual_zone',
        "source_virtual_zone": 'source_virtual_zone',
        "destination_virtual_zone_id": 'destination_virtual_zone_id',
        "source_virtual_zone_id": 'source_virtual_zone_id',
        "policy_id": 'policy_id',
        "id": 'id',
        "site_id": 'site_id'
    }

    _optionals = [
        'destination_virtual_zone',
        'source_virtual_zone',
        'destination_virtual_zone_id',
        'source_virtual_zone_id',
        'policy_id',
        'id',
        'site_id',
    ]

    def __init__(self,
                 destination_virtual_zone=APIHelper.SKIP,
                 source_virtual_zone=APIHelper.SKIP,
                 destination_virtual_zone_id=APIHelper.SKIP,
                 source_virtual_zone_id=APIHelper.SKIP,
                 policy_id=APIHelper.SKIP,
                 id=APIHelper.SKIP,
                 site_id=APIHelper.SKIP):
        """Constructor for the VirtualZones class"""

        # Initialize members of the class
        if destination_virtual_zone is not APIHelper.SKIP:
            self.destination_virtual_zone = destination_virtual_zone 
        if source_virtual_zone is not APIHelper.SKIP:
            self.source_virtual_zone = source_virtual_zone 
        if destination_virtual_zone_id is not APIHelper.SKIP:
            self.destination_virtual_zone_id = destination_virtual_zone_id 
        if source_virtual_zone_id is not APIHelper.SKIP:
            self.source_virtual_zone_id = source_virtual_zone_id 
        if policy_id is not APIHelper.SKIP:
            self.policy_id = policy_id 
        if id is not APIHelper.SKIP:
            self.id = id 
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        destination_virtual_zone = DestinationVirtualZone.from_dictionary(dictionary.get('destination_virtual_zone')) if 'destination_virtual_zone' in dictionary.keys() else APIHelper.SKIP
        source_virtual_zone = DestinationVirtualZone.from_dictionary(dictionary.get('source_virtual_zone')) if 'source_virtual_zone' in dictionary.keys() else APIHelper.SKIP
        destination_virtual_zone_id = dictionary.get("destination_virtual_zone_id") if dictionary.get("destination_virtual_zone_id") else APIHelper.SKIP
        source_virtual_zone_id = dictionary.get("source_virtual_zone_id") if dictionary.get("source_virtual_zone_id") else APIHelper.SKIP
        policy_id = dictionary.get("policy_id") if dictionary.get("policy_id") else APIHelper.SKIP
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        site_id = dictionary.get("site_id") if dictionary.get("site_id") else APIHelper.SKIP
        # Return an object of this model
        return cls(destination_virtual_zone,
                   source_virtual_zone,
                   destination_virtual_zone_id,
                   source_virtual_zone_id,
                   policy_id,
                   id,
                   site_id)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper


class UpdateLicenseResponse(object):

    """Implementation of the 'UpdateLicenseResponse' model.

    TODO: type model description here.

    Attributes:
        success (bool): TODO: type description here.
        message (string): TODO: type description here.
        status (StatusEnum): TODO: type description here.
        expiration_date (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "success": 'success',
        "message": 'message',
        "status": 'status',
        "expiration_date": 'expiration_date'
    }

    _optionals = [
        'status',
        'expiration_date',
    ]

    def __init__(self,
                 success=None,
                 message=None,
                 status=APIHelper.SKIP,
                 expiration_date=APIHelper.SKIP):
        """Constructor for the UpdateLicenseResponse class"""

        # Initialize members of the class
        self.success = success 
        self.message = message 
        if status is not APIHelper.SKIP:
            self.status = status 
        if expiration_date is not APIHelper.SKIP:
            self.expiration_date = expiration_date 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        success = dictionary.get("success") if "success" in dictionary.keys() else None
        message = dictionary.get("message") if dictionary.get("message") else None
        status = dictionary.get("status") if dictionary.get("status") else APIHelper.SKIP
        expiration_date = dictionary.get("expiration_date") if dictionary.get("expiration_date") else APIHelper.SKIP
        # Return an object of this model
        return cls(success,
                   message,
                   status,
                   expiration_date)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper


class GetLicenseDetailsResponse(object):

    """Implementation of the 'GetLicenseDetailsResponse' model.

    TODO: type model description here.

    Attributes:
        machine_uuid (string): TODO: type description here.
        expiration_date (string): TODO: type description here.
        status (StatusEnum): TODO: type description here.
        existing_license_key (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "machine_uuid": 'machine_uuid',
        "expiration_date": 'expiration_date',
        "status": 'status',
        "existing_license_key": 'existing_license_key'
    }

    _optionals = [
        'expiration_date',
        'status',
        'existing_license_key',
    ]

    def __init__(self,
                 machine_uuid=None,
                 expiration_date=APIHelper.SKIP,
                 status=APIHelper.SKIP,
                 existing_license_key=APIHelper.SKIP):
        """Constructor for the GetLicenseDetailsResponse class"""

        # Initialize members of the class
        self.machine_uuid = machine_uuid 
        if expiration_date is not APIHelper.SKIP:
            self.expiration_date = expiration_date 
        if status is not APIHelper.SKIP:
            self.status = status 
        if existing_license_key is not APIHelper.SKIP:
            self.existing_license_key = existing_license_key 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        machine_uuid = dictionary.get("machine_uuid") if dictionary.get("machine_uuid") else None
        expiration_date = dictionary.get("expiration_date") if dictionary.get("expiration_date") else APIHelper.SKIP
        status = dictionary.get("status") if dictionary.get("status") else APIHelper.SKIP
        existing_license_key = dictionary.get("existing_license_key") if dictionary.get("existing_license_key") else APIHelper.SKIP
        # Return an object of this model
        return cls(machine_uuid,
                   expiration_date,
                   status,
                   existing_license_key)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from apimatic_core.authentication.header_auth import HeaderAuth


class CustomHeaderAuthentication(HeaderAuth):

    @property
    def error_message(self):
        """Display error message on occurrence of authentication failure
        in CustomHeaderAuthentication

        """
        return "CustomHeaderAuthentication: Authorization is undefined."

    def __init__(self, authorization):
        auth_params = {}
        if authorization:
            auth_params["Authorization"] = authorization
        super().__init__(auth_params=auth_params)
        self._authorization = authorization



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper


class BaseTask(object):

    """Implementation of the 'BaseTask' model.

    TODO: type model description here.

    Attributes:
        allowed_days (string): A string that represents specific days in a
            week, Sunday being 0 and Friday being 6. To select more than a
            specific day just concatenate the day number to the string
        allowed_run_time_end (string): TODO: type description here.
        allowed_run_time_start (string): TODO: type description here.
        mtype (int): TODO: type description here.
        end_time (string): TODO: type description here.
        interval (string): TODO: type description here.
        is_recurring (bool): TODO: type description here.
        name (string): TODO: type description here.
        resource_id (string): TODO: type description here.
        site_id (float): TODO: type description here.
        status (string): TODO: type description here.
        valid (bool): TODO: type description here.
        start_time (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "allowed_days": 'allowed_days',
        "allowed_run_time_end": 'allowed_run_time_end',
        "allowed_run_time_start": 'allowed_run_time_start',
        "mtype": 'type',
        "end_time": 'end_time',
        "interval": 'interval',
        "is_recurring": 'is_recurring',
        "name": 'name',
        "resource_id": 'resource_id',
        "site_id": 'site_id',
        "status": 'status',
        "valid": 'valid',
        "start_time": 'start_time'
    }

    _optionals = [
        'allowed_days',
        'allowed_run_time_end',
        'allowed_run_time_start',
        'mtype',
        'end_time',
        'interval',
        'is_recurring',
        'name',
        'resource_id',
        'site_id',
        'status',
        'valid',
        'start_time',
    ]

    def __init__(self,
                 allowed_days=APIHelper.SKIP,
                 allowed_run_time_end=APIHelper.SKIP,
                 allowed_run_time_start=APIHelper.SKIP,
                 mtype=APIHelper.SKIP,
                 end_time=APIHelper.SKIP,
                 interval=APIHelper.SKIP,
                 is_recurring=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 resource_id=APIHelper.SKIP,
                 site_id=APIHelper.SKIP,
                 status=APIHelper.SKIP,
                 valid=APIHelper.SKIP,
                 start_time=APIHelper.SKIP):
        """Constructor for the BaseTask class"""

        # Initialize members of the class
        if allowed_days is not APIHelper.SKIP:
            self.allowed_days = allowed_days 
        if allowed_run_time_end is not APIHelper.SKIP:
            self.allowed_run_time_end = allowed_run_time_end 
        if allowed_run_time_start is not APIHelper.SKIP:
            self.allowed_run_time_start = allowed_run_time_start 
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype 
        if end_time is not APIHelper.SKIP:
            self.end_time = end_time 
        if interval is not APIHelper.SKIP:
            self.interval = interval 
        if is_recurring is not APIHelper.SKIP:
            self.is_recurring = is_recurring 
        if name is not APIHelper.SKIP:
            self.name = name 
        if resource_id is not APIHelper.SKIP:
            self.resource_id = resource_id 
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id 
        if status is not APIHelper.SKIP:
            self.status = status 
        if valid is not APIHelper.SKIP:
            self.valid = valid 
        if start_time is not APIHelper.SKIP:
            self.start_time = start_time 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        allowed_days = dictionary.get("allowed_days") if dictionary.get("allowed_days") else APIHelper.SKIP
        allowed_run_time_end = dictionary.get("allowed_run_time_end") if dictionary.get("allowed_run_time_end") else APIHelper.SKIP
        allowed_run_time_start = dictionary.get("allowed_run_time_start") if dictionary.get("allowed_run_time_start") else APIHelper.SKIP
        mtype = dictionary.get("type") if dictionary.get("type") else APIHelper.SKIP
        end_time = dictionary.get("end_time") if dictionary.get("end_time") else APIHelper.SKIP
        interval = dictionary.get("interval") if dictionary.get("interval") else APIHelper.SKIP
        is_recurring = dictionary.get("is_recurring") if "is_recurring" in dictionary.keys() else APIHelper.SKIP
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        resource_id = dictionary.get("resource_id") if dictionary.get("resource_id") else APIHelper.SKIP
        site_id = dictionary.get("site_id") if dictionary.get("site_id") else APIHelper.SKIP
        status = dictionary.get("status") if dictionary.get("status") else APIHelper.SKIP
        valid = dictionary.get("valid") if "valid" in dictionary.keys() else APIHelper.SKIP
        start_time = dictionary.get("start_time") if dictionary.get("start_time") else APIHelper.SKIP
        # Return an object of this model
        return cls(allowed_days,
                   allowed_run_time_end,
                   allowed_run_time_start,
                   mtype,
                   end_time,
                   interval,
                   is_recurring,
                   name,
                   resource_id,
                   site_id,
                   status,
                   valid,
                   start_time)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Sort5Enum(object):

    """Implementation of the 'sort5' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_DESCRIPTION: TODO: type description here.
        DESCRIPTION: TODO: type description here.
        ENUM_NAME: TODO: type description here.
        NAME: TODO: type description here.
        ENUM_SITE_ID: TODO: type description here.
        SITE_ID: TODO: type description here.
        ENUM_ID: TODO: type description here.
        ID: TODO: type description here.

    """

    ENUM_DESCRIPTION = '-description'

    DESCRIPTION = 'description'

    ENUM_NAME = '-name'

    NAME = 'name'

    ENUM_SITE_ID = '-site_id'

    SITE_ID = 'site_id'

    ENUM_ID = '-id'

    ID = 'id'



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper


class Site(object):

    """Implementation of the 'Site' model.

    TODO: type model description here.

    Attributes:
        address (string): TODO: type description here.
        assets_count (int): TODO: type description here.
        auto_transition_to_operational (bool): TODO: type description here.
        description (string): TODO: type description here.
        id (int): TODO: type description here.
        image_url (string): TODO: type description here.
        installed_date (string): TODO: type description here.
        integrity_alerts_severity_number (int): TODO: type description here.
        integrity_alerts_severity_name (string): TODO: type description here.
        is_connected (bool): TODO: type description here.
        name (string): TODO: type description here.
        score (int): TODO: type description here.
        security_alerts_severity_number (int): TODO: type description here.
        security_alerts_severity_name (string): TODO: type description here.
        training_mode (bool): TODO: type description here.
        unresolved_integrity_alerts_count (int): TODO: type description here.
        unresolved_security_alerts_count (int): TODO: type description here.
        version (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "address": 'address',
        "assets_count": 'assets_count',
        "auto_transition_to_operational": 'auto_transition_to_operational',
        "description": 'description',
        "id": 'id',
        "image_url": 'image_url',
        "installed_date": 'installed_date',
        "integrity_alerts_severity_number": 'integrity_alerts_severity_number',
        "integrity_alerts_severity_name": 'integrity_alerts_severity_name',
        "is_connected": 'is_connected',
        "name": 'name',
        "score": 'score',
        "security_alerts_severity_number": 'security_alerts_severity_number',
        "security_alerts_severity_name": 'security_alerts_severity_name',
        "training_mode": 'training_mode',
        "unresolved_integrity_alerts_count": 'unresolved_integrity_alerts_count',
        "unresolved_security_alerts_count": 'unresolved_security_alerts_count',
        "version": 'version'
    }

    _optionals = [
        'address',
        'assets_count',
        'auto_transition_to_operational',
        'description',
        'id',
        'image_url',
        'installed_date',
        'integrity_alerts_severity_number',
        'integrity_alerts_severity_name',
        'is_connected',
        'name',
        'score',
        'security_alerts_severity_number',
        'security_alerts_severity_name',
        'training_mode',
        'unresolved_integrity_alerts_count',
        'unresolved_security_alerts_count',
        'version',
    ]

    def __init__(self,
                 address=APIHelper.SKIP,
                 assets_count=APIHelper.SKIP,
                 auto_transition_to_operational=APIHelper.SKIP,
                 description=APIHelper.SKIP,
                 id=APIHelper.SKIP,
                 image_url=APIHelper.SKIP,
                 installed_date=APIHelper.SKIP,
                 integrity_alerts_severity_number=APIHelper.SKIP,
                 integrity_alerts_severity_name=APIHelper.SKIP,
                 is_connected=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 score=APIHelper.SKIP,
                 security_alerts_severity_number=APIHelper.SKIP,
                 security_alerts_severity_name=APIHelper.SKIP,
                 training_mode=APIHelper.SKIP,
                 unresolved_integrity_alerts_count=APIHelper.SKIP,
                 unresolved_security_alerts_count=APIHelper.SKIP,
                 version=APIHelper.SKIP):
        """Constructor for the Site class"""

        # Initialize members of the class
        if address is not APIHelper.SKIP:
            self.address = address 
        if assets_count is not APIHelper.SKIP:
            self.assets_count = assets_count 
        if auto_transition_to_operational is not APIHelper.SKIP:
            self.auto_transition_to_operational = auto_transition_to_operational 
        if description is not APIHelper.SKIP:
            self.description = description 
        if id is not APIHelper.SKIP:
            self.id = id 
        if image_url is not APIHelper.SKIP:
            self.image_url = image_url 
        if installed_date is not APIHelper.SKIP:
            self.installed_date = installed_date 
        if integrity_alerts_severity_number is not APIHelper.SKIP:
            self.integrity_alerts_severity_number = integrity_alerts_severity_number 
        if integrity_alerts_severity_name is not APIHelper.SKIP:
            self.integrity_alerts_severity_name = integrity_alerts_severity_name 
        if is_connected is not APIHelper.SKIP:
            self.is_connected = is_connected 
        if name is not APIHelper.SKIP:
            self.name = name 
        if score is not APIHelper.SKIP:
            self.score = score 
        if security_alerts_severity_number is not APIHelper.SKIP:
            self.security_alerts_severity_number = security_alerts_severity_number 
        if security_alerts_severity_name is not APIHelper.SKIP:
            self.security_alerts_severity_name = security_alerts_severity_name 
        if training_mode is not APIHelper.SKIP:
            self.training_mode = training_mode 
        if unresolved_integrity_alerts_count is not APIHelper.SKIP:
            self.unresolved_integrity_alerts_count = unresolved_integrity_alerts_count 
        if unresolved_security_alerts_count is not APIHelper.SKIP:
            self.unresolved_security_alerts_count = unresolved_security_alerts_count 
        if version is not APIHelper.SKIP:
            self.version = version 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        address = dictionary.get("address") if dictionary.get("address") else APIHelper.SKIP
        assets_count = dictionary.get("assets_count") if dictionary.get("assets_count") else APIHelper.SKIP
        auto_transition_to_operational = dictionary.get("auto_transition_to_operational") if "auto_transition_to_operational" in dictionary.keys() else APIHelper.SKIP
        description = dictionary.get("description") if dictionary.get("description") else APIHelper.SKIP
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        image_url = dictionary.get("image_url") if dictionary.get("image_url") else APIHelper.SKIP
        installed_date = dictionary.get("installed_date") if dictionary.get("installed_date") else APIHelper.SKIP
        integrity_alerts_severity_number = dictionary.get("integrity_alerts_severity_number") if dictionary.get("integrity_alerts_severity_number") else APIHelper.SKIP
        integrity_alerts_severity_name = dictionary.get("integrity_alerts_severity_name") if dictionary.get("integrity_alerts_severity_name") else APIHelper.SKIP
        is_connected = dictionary.get("is_connected") if "is_connected" in dictionary.keys() else APIHelper.SKIP
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        score = dictionary.get("score") if dictionary.get("score") else APIHelper.SKIP
        security_alerts_severity_number = dictionary.get("security_alerts_severity_number") if dictionary.get("security_alerts_severity_number") else APIHelper.SKIP
        security_alerts_severity_name = dictionary.get("security_alerts_severity_name") if dictionary.get("security_alerts_severity_name") else APIHelper.SKIP
        training_mode = dictionary.get("training_mode") if "training_mode" in dictionary.keys() else APIHelper.SKIP
        unresolved_integrity_alerts_count = dictionary.get("unresolved_integrity_alerts_count") if dictionary.get("unresolved_integrity_alerts_count") else APIHelper.SKIP
        unresolved_security_alerts_count = dictionary.get("unresolved_security_alerts_count") if dictionary.get("unresolved_security_alerts_count") else APIHelper.SKIP
        version = dictionary.get("version") if dictionary.get("version") else APIHelper.SKIP
        # Return an object of this model
        return cls(address,
                   assets_count,
                   auto_transition_to_operational,
                   description,
                   id,
                   image_url,
                   installed_date,
                   integrity_alerts_severity_number,
                   integrity_alerts_severity_name,
                   is_connected,
                   name,
                   score,
                   security_alerts_severity_number,
                   security_alerts_severity_name,
                   training_mode,
                   unresolved_integrity_alerts_count,
                   unresolved_security_alerts_count,
                   version)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper
from ctddocumentation.models.slim_insight import SlimInsight


class AssetsWithInsights(object):

    """Implementation of the 'AssetsWithInsights' model.

    TODO: type model description here.

    Attributes:
        resource_id (string): TODO: type description here.
        id (int): TODO: type description here.
        site_id (int): TODO: type description here.
        asset_type (int): The number represents the Asset type
        asset_type___name (string): The label of the Asset type
        criticality (int): The number represent the Asset criticality
        criticality___name (string): The label of the Asset criticality
        firmware (string): The Asset firmware
        ghost (bool): Asset who has only incoming communications, i.e. asset
            that never replied
        insights (list of SlimInsight): TODO: type description here.
        i_pv_4 (list of string): The IPv4 addresses related to the Asset
        i_pv_6 (list of string): The IPv6 addresses related to the Asset
        mac (list of string): The MAC addresses that related to the Asset
        model (string): The Asset's model
        name (string): The Asset's name
        network_id (int): The Asset's network ID number
        risk_level (int): The level of the Asset's vulnerability to attacks
        site_name (string): The name of the Site that the Asset is related to
        total_cves_count (int): The total CVEs number that are related to the
            Asset
        vendor (string): the Asset's vendor

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "resource_id": 'resource_id',
        "id": 'id',
        "site_id": 'site_id',
        "asset_type": 'asset_type',
        "asset_type___name": 'asset_type__(name)',
        "criticality": 'criticality',
        "criticality___name": 'criticality__(name)',
        "firmware": 'firmware',
        "ghost": 'ghost',
        "insights": 'insights',
        "i_pv_4": 'IPv4',
        "i_pv_6": 'IPv6',
        "mac": 'mac',
        "model": 'model',
        "name": 'name',
        "network_id": 'network_id',
        "risk_level": 'risk_level',
        "site_name": 'site_name',
        "total_cves_count": 'total_cves_count',
        "vendor": 'vendor'
    }

    _optionals = [
        'resource_id',
        'id',
        'site_id',
        'asset_type',
        'asset_type___name',
        'criticality',
        'criticality___name',
        'firmware',
        'ghost',
        'insights',
        'i_pv_4',
        'i_pv_6',
        'mac',
        'model',
        'name',
        'network_id',
        'risk_level',
        'site_name',
        'total_cves_count',
        'vendor',
    ]

    def __init__(self,
                 resource_id=APIHelper.SKIP,
                 id=APIHelper.SKIP,
                 site_id=APIHelper.SKIP,
                 asset_type=APIHelper.SKIP,
                 asset_type___name=APIHelper.SKIP,
                 criticality=APIHelper.SKIP,
                 criticality___name=APIHelper.SKIP,
                 firmware=APIHelper.SKIP,
                 ghost=APIHelper.SKIP,
                 insights=APIHelper.SKIP,
                 i_pv_4=APIHelper.SKIP,
                 i_pv_6=APIHelper.SKIP,
                 mac=APIHelper.SKIP,
                 model=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 network_id=APIHelper.SKIP,
                 risk_level=APIHelper.SKIP,
                 site_name=APIHelper.SKIP,
                 total_cves_count=APIHelper.SKIP,
                 vendor=APIHelper.SKIP):
        """Constructor for the AssetsWithInsights class"""

        # Initialize members of the class
        if resource_id is not APIHelper.SKIP:
            self.resource_id = resource_id 
        if id is not APIHelper.SKIP:
            self.id = id 
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id 
        if asset_type is not APIHelper.SKIP:
            self.asset_type = asset_type 
        if asset_type___name is not APIHelper.SKIP:
            self.asset_type___name = asset_type___name 
        if criticality is not APIHelper.SKIP:
            self.criticality = criticality 
        if criticality___name is not APIHelper.SKIP:
            self.criticality___name = criticality___name 
        if firmware is not APIHelper.SKIP:
            self.firmware = firmware 
        if ghost is not APIHelper.SKIP:
            self.ghost = ghost 
        if insights is not APIHelper.SKIP:
            self.insights = insights 
        if i_pv_4 is not APIHelper.SKIP:
            self.i_pv_4 = i_pv_4 
        if i_pv_6 is not APIHelper.SKIP:
            self.i_pv_6 = i_pv_6 
        if mac is not APIHelper.SKIP:
            self.mac = mac 
        if model is not APIHelper.SKIP:
            self.model = model 
        if name is not APIHelper.SKIP:
            self.name = name 
        if network_id is not APIHelper.SKIP:
            self.network_id = network_id 
        if risk_level is not APIHelper.SKIP:
            self.risk_level = risk_level 
        if site_name is not APIHelper.SKIP:
            self.site_name = site_name 
        if total_cves_count is not APIHelper.SKIP:
            self.total_cves_count = total_cves_count 
        if vendor is not APIHelper.SKIP:
            self.vendor = vendor 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        resource_id = dictionary.get("resource_id") if dictionary.get("resource_id") else APIHelper.SKIP
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        site_id = dictionary.get("site_id") if dictionary.get("site_id") else APIHelper.SKIP
        asset_type = dictionary.get("asset_type") if dictionary.get("asset_type") else APIHelper.SKIP
        asset_type___name = dictionary.get("asset_type__(name)") if dictionary.get("asset_type__(name)") else APIHelper.SKIP
        criticality = dictionary.get("criticality") if dictionary.get("criticality") else APIHelper.SKIP
        criticality___name = dictionary.get("criticality__(name)") if dictionary.get("criticality__(name)") else APIHelper.SKIP
        firmware = dictionary.get("firmware") if dictionary.get("firmware") else APIHelper.SKIP
        ghost = dictionary.get("ghost") if "ghost" in dictionary.keys() else APIHelper.SKIP
        insights = None
        if dictionary.get('insights') is not None:
            insights = [SlimInsight.from_dictionary(x) for x in dictionary.get('insights')]
        else:
            insights = APIHelper.SKIP
        i_pv_4 = dictionary.get("IPv4") if dictionary.get("IPv4") else APIHelper.SKIP
        i_pv_6 = dictionary.get("IPv6") if dictionary.get("IPv6") else APIHelper.SKIP
        mac = dictionary.get("mac") if dictionary.get("mac") else APIHelper.SKIP
        model = dictionary.get("model") if dictionary.get("model") else APIHelper.SKIP
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        network_id = dictionary.get("network_id") if dictionary.get("network_id") else APIHelper.SKIP
        risk_level = dictionary.get("risk_level") if dictionary.get("risk_level") else APIHelper.SKIP
        site_name = dictionary.get("site_name") if dictionary.get("site_name") else APIHelper.SKIP
        total_cves_count = dictionary.get("total_cves_count") if dictionary.get("total_cves_count") else APIHelper.SKIP
        vendor = dictionary.get("vendor") if dictionary.get("vendor") else APIHelper.SKIP
        # Return an object of this model
        return cls(resource_id,
                   id,
                   site_id,
                   asset_type,
                   asset_type___name,
                   criticality,
                   criticality___name,
                   firmware,
                   ghost,
                   insights,
                   i_pv_4,
                   i_pv_6,
                   mac,
                   model,
                   name,
                   network_id,
                   risk_level,
                   site_name,
                   total_cves_count,
                   vendor)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SiteListSlimEnum(object):

    """Implementation of the 'siteListSlimEnum' enum.

    TODO: type enum description here.

    Attributes:
        SITE_LIST_SLIM: TODO: type description here.

    """

    SITE_LIST_SLIM = 'site_list_slim'



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper
from ctddocumentation.models.object import Object


class GetQueriesIdsAndAssignedTaskResponse(object):

    """Implementation of the 'GetQueriesIdsAndAssignedTaskResponse' model.

    TODO: type model description here.

    Attributes:
        queries (list of object): List of lists that contains the id and name
            of each query
        selected_queries (list of int): List of lists that contains the id of
            each query assigned to the task

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "queries": 'queries',
        "selected_queries": 'selected_queries'
    }

    _optionals = [
        'queries',
        'selected_queries',
    ]

    def __init__(self,
                 queries=APIHelper.SKIP,
                 selected_queries=APIHelper.SKIP):
        """Constructor for the GetQueriesIdsAndAssignedTaskResponse class"""

        # Initialize members of the class
        if queries is not APIHelper.SKIP:
            self.queries = queries 
        if selected_queries is not APIHelper.SKIP:
            self.selected_queries = selected_queries 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        queries = None
        if dictionary.get('queries') is not None:
            queries = [Object.from_dictionary(x) for x in dictionary.get('queries')]
        else:
            queries = APIHelper.SKIP
        selected_queries = dictionary.get("selected_queries") if dictionary.get("selected_queries") else APIHelper.SKIP
        # Return an object of this model
        return cls(queries,
                   selected_queries)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper
from ctddocumentation.models.actionable import Actionable
from ctddocumentation.models.actionable_asset import ActionableAsset
from ctddocumentation.models.actionable_cap import ActionableCap
from ctddocumentation.models.actionable_information import ActionableInformation
from ctddocumentation.models.actionable_policy import ActionablePolicy
from ctddocumentation.models.indicators import Indicators
from ctddocumentation.models.network import Network


class Alert(object):

    """Implementation of the 'Alert' model.

    TODO: type model description here.

    Attributes:
        resource_id (string): TODO: type description here.
        id (int): TODO: type description here.
        site_id (int): TODO: type description here.
        is_qualified (bool): TODO: type description here.
        actionable_diffs (list of Actionable): TODO: type description here.
        actionable_suspicious_files (list of Actionable): TODO: type
            description here.
        actionable_information (list of ActionableInformation): TODO: type
            description here.
        actionable_policies (list of ActionablePolicy): TODO: type description
            here.
        actionable_assets (list of ActionableAsset): TODO: type description
            here.
        actionable_caps (list of ActionableCap): TODO: type description here.
        significant_indicators (list of Indicators): TODO: type description
            here.
        alert_indicators (list of Indicators): TODO: type description here.
        threat_type (int): TODO: type description here.
        category_number (int): TODO: type description here.
        category_name (string): TODO: type description here.
        description (string): TODO: type description here.
        network (Network): TODO: type description here.
        score (int): TODO: type description here.
        severity_number (int): TODO: type description here.
        severity_name (string): TODO: type description here.
        resolution_number (int): TODO: type description here.
        resolution_name (string): TODO: type description here.
        resolved (bool): TODO: type description here.
        relevant (bool): TODO: type description here.
        protocol (string): TODO: type description here.
        network_id (int): TODO: type description here.
        story_id (int): TODO: type description here.
        actionable_virtual_zones_names (list of string): TODO: type
            description here.
        story_group_name (list of string): TODO: type description here.
        timestamp (string): TODO: type description here.
        last_updated (string): TODO: type description here.
        type_number (int): TODO: type description here.
        type_name (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "resource_id": 'resource_id',
        "id": 'id',
        "site_id": 'site_id',
        "is_qualified": 'is_qualified',
        "actionable_diffs": 'actionable_diffs',
        "actionable_suspicious_files": 'actionable_suspicious_files',
        "actionable_information": 'actionable_information',
        "actionable_policies": 'actionable_policies',
        "actionable_assets": 'actionable_assets',
        "actionable_caps": 'actionable_caps',
        "significant_indicators": 'significant_indicators',
        "alert_indicators": 'alert_indicators',
        "threat_type": 'threat_type',
        "category_number": 'category_number',
        "category_name": 'category_name',
        "description": 'description',
        "network": 'network',
        "score": 'score',
        "severity_number": 'severity_number',
        "severity_name": 'severity_name',
        "resolution_number": 'resolution_number',
        "resolution_name": 'resolution_name',
        "resolved": 'resolved',
        "relevant": 'relevant',
        "protocol": 'protocol',
        "network_id": 'network_id',
        "story_id": 'story_id',
        "actionable_virtual_zones_names": 'actionable_virtual_zones_names',
        "story_group_name": 'story_group_name',
        "timestamp": 'timestamp',
        "last_updated": 'last_updated',
        "type_number": 'type_number',
        "type_name": 'type_name'
    }

    _optionals = [
        'resource_id',
        'id',
        'site_id',
        'is_qualified',
        'actionable_diffs',
        'actionable_suspicious_files',
        'actionable_information',
        'actionable_policies',
        'actionable_assets',
        'actionable_caps',
        'significant_indicators',
        'alert_indicators',
        'threat_type',
        'category_number',
        'category_name',
        'description',
        'network',
        'score',
        'severity_number',
        'severity_name',
        'resolution_number',
        'resolution_name',
        'resolved',
        'relevant',
        'protocol',
        'network_id',
        'story_id',
        'actionable_virtual_zones_names',
        'story_group_name',
        'timestamp',
        'last_updated',
        'type_number',
        'type_name',
    ]

    def __init__(self,
                 resource_id=APIHelper.SKIP,
                 id=APIHelper.SKIP,
                 site_id=APIHelper.SKIP,
                 is_qualified=APIHelper.SKIP,
                 actionable_diffs=APIHelper.SKIP,
                 actionable_suspicious_files=APIHelper.SKIP,
                 actionable_information=APIHelper.SKIP,
                 actionable_policies=APIHelper.SKIP,
                 actionable_assets=APIHelper.SKIP,
                 actionable_caps=APIHelper.SKIP,
                 significant_indicators=APIHelper.SKIP,
                 alert_indicators=APIHelper.SKIP,
                 threat_type=APIHelper.SKIP,
                 category_number=APIHelper.SKIP,
                 category_name=APIHelper.SKIP,
                 description=APIHelper.SKIP,
                 network=APIHelper.SKIP,
                 score=APIHelper.SKIP,
                 severity_number=APIHelper.SKIP,
                 severity_name=APIHelper.SKIP,
                 resolution_number=APIHelper.SKIP,
                 resolution_name=APIHelper.SKIP,
                 resolved=APIHelper.SKIP,
                 relevant=APIHelper.SKIP,
                 protocol=APIHelper.SKIP,
                 network_id=APIHelper.SKIP,
                 story_id=APIHelper.SKIP,
                 actionable_virtual_zones_names=APIHelper.SKIP,
                 story_group_name=APIHelper.SKIP,
                 timestamp=APIHelper.SKIP,
                 last_updated=APIHelper.SKIP,
                 type_number=APIHelper.SKIP,
                 type_name=APIHelper.SKIP):
        """Constructor for the Alert class"""

        # Initialize members of the class
        if resource_id is not APIHelper.SKIP:
            self.resource_id = resource_id 
        if id is not APIHelper.SKIP:
            self.id = id 
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id 
        if is_qualified is not APIHelper.SKIP:
            self.is_qualified = is_qualified 
        if actionable_diffs is not APIHelper.SKIP:
            self.actionable_diffs = actionable_diffs 
        if actionable_suspicious_files is not APIHelper.SKIP:
            self.actionable_suspicious_files = actionable_suspicious_files 
        if actionable_information is not APIHelper.SKIP:
            self.actionable_information = actionable_information 
        if actionable_policies is not APIHelper.SKIP:
            self.actionable_policies = actionable_policies 
        if actionable_assets is not APIHelper.SKIP:
            self.actionable_assets = actionable_assets 
        if actionable_caps is not APIHelper.SKIP:
            self.actionable_caps = actionable_caps 
        if significant_indicators is not APIHelper.SKIP:
            self.significant_indicators = significant_indicators 
        if alert_indicators is not APIHelper.SKIP:
            self.alert_indicators = alert_indicators 
        if threat_type is not APIHelper.SKIP:
            self.threat_type = threat_type 
        if category_number is not APIHelper.SKIP:
            self.category_number = category_number 
        if category_name is not APIHelper.SKIP:
            self.category_name = category_name 
        if description is not APIHelper.SKIP:
            self.description = description 
        if network is not APIHelper.SKIP:
            self.network = network 
        if score is not APIHelper.SKIP:
            self.score = score 
        if severity_number is not APIHelper.SKIP:
            self.severity_number = severity_number 
        if severity_name is not APIHelper.SKIP:
            self.severity_name = severity_name 
        if resolution_number is not APIHelper.SKIP:
            self.resolution_number = resolution_number 
        if resolution_name is not APIHelper.SKIP:
            self.resolution_name = resolution_name 
        if resolved is not APIHelper.SKIP:
            self.resolved = resolved 
        if relevant is not APIHelper.SKIP:
            self.relevant = relevant 
        if protocol is not APIHelper.SKIP:
            self.protocol = protocol 
        if network_id is not APIHelper.SKIP:
            self.network_id = network_id 
        if story_id is not APIHelper.SKIP:
            self.story_id = story_id 
        if actionable_virtual_zones_names is not APIHelper.SKIP:
            self.actionable_virtual_zones_names = actionable_virtual_zones_names 
        if story_group_name is not APIHelper.SKIP:
            self.story_group_name = story_group_name 
        if timestamp is not APIHelper.SKIP:
            self.timestamp = timestamp 
        if last_updated is not APIHelper.SKIP:
            self.last_updated = last_updated 
        if type_number is not APIHelper.SKIP:
            self.type_number = type_number 
        if type_name is not APIHelper.SKIP:
            self.type_name = type_name 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        resource_id = dictionary.get("resource_id") if dictionary.get("resource_id") else APIHelper.SKIP
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        site_id = dictionary.get("site_id") if dictionary.get("site_id") else APIHelper.SKIP
        is_qualified = dictionary.get("is_qualified") if "is_qualified" in dictionary.keys() else APIHelper.SKIP
        actionable_diffs = None
        if dictionary.get('actionable_diffs') is not None:
            actionable_diffs = [Actionable.from_dictionary(x) for x in dictionary.get('actionable_diffs')]
        else:
            actionable_diffs = APIHelper.SKIP
        actionable_suspicious_files = None
        if dictionary.get('actionable_suspicious_files') is not None:
            actionable_suspicious_files = [Actionable.from_dictionary(x) for x in dictionary.get('actionable_suspicious_files')]
        else:
            actionable_suspicious_files = APIHelper.SKIP
        actionable_information = None
        if dictionary.get('actionable_information') is not None:
            actionable_information = [ActionableInformation.from_dictionary(x) for x in dictionary.get('actionable_information')]
        else:
            actionable_information = APIHelper.SKIP
        actionable_policies = None
        if dictionary.get('actionable_policies') is not None:
            actionable_policies = [ActionablePolicy.from_dictionary(x) for x in dictionary.get('actionable_policies')]
        else:
            actionable_policies = APIHelper.SKIP
        actionable_assets = None
        if dictionary.get('actionable_assets') is not None:
            actionable_assets = [ActionableAsset.from_dictionary(x) for x in dictionary.get('actionable_assets')]
        else:
            actionable_assets = APIHelper.SKIP
        actionable_caps = None
        if dictionary.get('actionable_caps') is not None:
            actionable_caps = [ActionableCap.from_dictionary(x) for x in dictionary.get('actionable_caps')]
        else:
            actionable_caps = APIHelper.SKIP
        significant_indicators = None
        if dictionary.get('significant_indicators') is not None:
            significant_indicators = [Indicators.from_dictionary(x) for x in dictionary.get('significant_indicators')]
        else:
            significant_indicators = APIHelper.SKIP
        alert_indicators = None
        if dictionary.get('alert_indicators') is not None:
            alert_indicators = [Indicators.from_dictionary(x) for x in dictionary.get('alert_indicators')]
        else:
            alert_indicators = APIHelper.SKIP
        threat_type = dictionary.get("threat_type") if dictionary.get("threat_type") else APIHelper.SKIP
        category_number = dictionary.get("category_number") if dictionary.get("category_number") else APIHelper.SKIP
        category_name = dictionary.get("category_name") if dictionary.get("category_name") else APIHelper.SKIP
        description = dictionary.get("description") if dictionary.get("description") else APIHelper.SKIP
        network = Network.from_dictionary(dictionary.get('network')) if 'network' in dictionary.keys() else APIHelper.SKIP
        score = dictionary.get("score") if dictionary.get("score") else APIHelper.SKIP
        severity_number = dictionary.get("severity_number") if dictionary.get("severity_number") else APIHelper.SKIP
        severity_name = dictionary.get("severity_name") if dictionary.get("severity_name") else APIHelper.SKIP
        resolution_number = dictionary.get("resolution_number") if dictionary.get("resolution_number") else APIHelper.SKIP
        resolution_name = dictionary.get("resolution_name") if dictionary.get("resolution_name") else APIHelper.SKIP
        resolved = dictionary.get("resolved") if "resolved" in dictionary.keys() else APIHelper.SKIP
        relevant = dictionary.get("relevant") if "relevant" in dictionary.keys() else APIHelper.SKIP
        protocol = dictionary.get("protocol") if dictionary.get("protocol") else APIHelper.SKIP
        network_id = dictionary.get("network_id") if dictionary.get("network_id") else APIHelper.SKIP
        story_id = dictionary.get("story_id") if dictionary.get("story_id") else APIHelper.SKIP
        actionable_virtual_zones_names = dictionary.get("actionable_virtual_zones_names") if dictionary.get("actionable_virtual_zones_names") else APIHelper.SKIP
        story_group_name = dictionary.get("story_group_name") if dictionary.get("story_group_name") else APIHelper.SKIP
        timestamp = dictionary.get("timestamp") if dictionary.get("timestamp") else APIHelper.SKIP
        last_updated = dictionary.get("last_updated") if dictionary.get("last_updated") else APIHelper.SKIP
        type_number = dictionary.get("type_number") if dictionary.get("type_number") else APIHelper.SKIP
        type_name = dictionary.get("type_name") if dictionary.get("type_name") else APIHelper.SKIP
        # Return an object of this model
        return cls(resource_id,
                   id,
                   site_id,
                   is_qualified,
                   actionable_diffs,
                   actionable_suspicious_files,
                   actionable_information,
                   actionable_policies,
                   actionable_assets,
                   actionable_caps,
                   significant_indicators,
                   alert_indicators,
                   threat_type,
                   category_number,
                   category_name,
                   description,
                   network,
                   score,
                   severity_number,
                   severity_name,
                   resolution_number,
                   resolution_name,
                   resolved,
                   relevant,
                   protocol,
                   network_id,
                   story_id,
                   actionable_virtual_zones_names,
                   story_group_name,
                   timestamp,
                   last_updated,
                   type_number,
                   type_name)
